@@ -18,4 +18,8 @@ class ListChild
     public $zone;
 
     public $weight;
+
+    public $preset;
+
+    public $name = '';
 }
\ No newline at end of file
