@@ -67,6 +67,7 @@ final class Requirements
      * filePermissionsPaths => $lcSettings['mustBeWritable'] (file_permissions)
      *
      * minMysqlVersion => LC_MYSQL_VERSION_MIN
+     * minMariadbVersion => LC_MARIADB_VERSION_MIN
      *
      * databaseDetails
      *
@@ -82,7 +83,7 @@ final class Requirements
             'configFileName'        => 'config.php',
             'defaultConfigFileName' => 'config.default.php',
 
-            'minPhpVersion'        => '5.4.0',
+            'minPhpVersion'        => '7.2.0',
             'maxPhpVersion'        => '',
             'forbiddenPhpVersions' => [],
 
@@ -92,7 +93,8 @@ final class Requirements
 
             'filePermissionsPaths' => self::getFilePermissionsPaths(),
 
-            'minMysqlVersion' => '5.0.3',
+            'minMysqlVersion' => '5.7.7',
+            'minMariadbVersion' => '10.2.4',
             'databaseDetails' => isset($config['database_details']) ? $config['database_details'] : [],
         ];
 
@@ -305,17 +307,11 @@ final class Requirements
                 'dependency'  => ['php_pdo_mysql'],
                 'environment' => [
                     'minMysqlVersion', // LC_MYSQL_VERSION_MIN
+                    'minMariadbVersion', // LC_MARIADB_VERSION_MIN
                     'databaseDetails',
                 ],
                 'checker'     => $this->getMysqlVersionChecker(),
             ],
-            'mysql_cache'              => [
-                'title'      => 'MySQL cache',
-                'state'      => self::STATE_UNCHECKED,
-                'level'      => self::LEVEL_OPTIONAL,
-                'dependency' => ['php_pdo_mysql'],
-                'checker'    => $this->getMysqlCacheChecker(),
-            ],
             'php_gdlib'                => [
                 'title'   => 'GDlib extension',
                 'state'   => self::STATE_UNCHECKED,
@@ -352,6 +348,12 @@ final class Requirements
                 'level'   => self::LEVEL_CRITICAL,
                 'checker' => $this->getFrameOptionsChecker(),
             ],
+            'loopback_request'       => [
+                'title'   => 'Loopback request',
+                'state'   => self::STATE_UNCHECKED,
+                'level'   => self::LEVEL_OPTIONAL,
+                'checker' => $this->getLoopbackRequestChecker(),
+            ],
         ];
     }
 
@@ -745,6 +747,7 @@ final class Requirements
             $innodb  = false;
             $version = 'unknown';
             $error   = '';
+            $rdbms = 'MySQL';
 
             if ($pdo) {
                 try {
@@ -755,6 +758,12 @@ final class Requirements
                 }
 
                 if ($version) {
+                    if ($this->isMariaDB($version)) {
+                        $versionParts = explode('-', $version);
+                        $version = (strtolower($versionParts[1]) == "mariadb") ? $versionParts[0] : $versionParts[1];
+                        $minMysqlVersion = $this->getEnvironment('minMariadbVersion');
+                        $rdbms = 'MariaDB';
+                    }
                     if (version_compare($version, $minMysqlVersion) < 0) {
                         return [
                             false,
@@ -762,6 +771,7 @@ final class Requirements
                             [
                                 'version'         => $version,
                                 'minMysqlVersion' => $minMysqlVersion,
+                                'rdbms'           => $rdbms
                             ],
                         ];
 
@@ -796,45 +806,6 @@ final class Requirements
         };
     }
 
-    /**
-     * @return \Closure
-     */
-    private function getMysqlCacheChecker()
-    {
-        return function () {
-            $pdo = $this->getPDO();
-            $result = true;
-            $haveQueryCache = $queryCacheType = $queryCacheSize = [];
-            if ($pdo) {
-                $statement = $pdo->prepare('SHOW VARIABLES LIKE \'have_query_cache\';');
-                $statement->execute();
-                $haveQueryCache = $statement->fetch();
-
-                $statement = $pdo->prepare('SHOW VARIABLES LIKE \'query_cache_type\';');
-                $statement->execute();
-                $queryCacheType = $statement->fetch();
-
-                $statement = $pdo->prepare('SHOW VARIABLES LIKE \'query_cache_size\';');
-                $statement->execute();
-                $queryCacheSize = $statement->fetch();
-
-                $result = (isset($haveQueryCache['Value']) ? strtolower($haveQueryCache['Value']) === 'yes' : false)
-                    && (isset($queryCacheType['Value']) ? in_array(strtolower($queryCacheType['Value']), ['on', '1'], true) : false)
-                    && (isset($queryCacheSize['Value']) ? ((int)$queryCacheSize['Value']) > 0 : false);
-            }
-
-            return [
-                $result,
-                'error_message_1',
-                [
-                    'have_query_cache' => isset($haveQueryCache['Value']) ? $haveQueryCache['Value'] : 'unknown',
-                    'query_cache_type' => isset($queryCacheType['Value']) ? $queryCacheType['Value'] : 'unknown',
-                    'query_cache_size' => isset($queryCacheSize['Value']) ? $queryCacheSize['Value'] : 'unknown',
-                ],
-            ];
-        };
-    }
-
     /**
      * @return \Closure
      */
@@ -871,25 +842,10 @@ final class Requirements
     private function getPhpPharChecker()
     {
         return function () {
-            $result  = false;
-            $version = '';
-
-            if (extension_loaded('Phar')) {
-                $result  = true;
-                $phpInfo = $this->getPhpInfo();
-
-                if (!empty($phpInfo['phar_ext_ver'])) {
-                    $version = trim($phpInfo['phar_ext_ver']);
-                    $result  = version_compare($version, '2.0.1') >= 0;
-                }
-            }
-
             return [
-                $result,
-                'error_message_1', // Phar extension v.2.0.1 or later required to get upgrades and install modules. Otherwise this features may not work properly.
-                [
-                    'version' => $version,
-                ],
+                extension_loaded('Phar'),
+                'error_message_1',
+                []
             ];
         };
     }
@@ -1018,6 +974,55 @@ final class Requirements
         };
     }
 
+    /**
+     * @return \Closure
+     */
+    private function getLoopbackRequestChecker()
+    {
+        return function () {
+            $result = true;
+
+            if (
+                function_exists('curl_init')
+                && function_exists('curl_version')
+                && isset($_SERVER['HTTP_HOST'])
+                && 'cli' !== PHP_SAPI
+            ) {
+                $adminScript = \Includes\Utils\FileManager::isFileReadable(\XLite::getAdminScript())
+                    ? \XLite::getAdminScript()
+                    : \XLite::ADMIN_SELF;
+
+                $customerScript = \Includes\Utils\FileManager::isFileReadable(\XLite::getCustomerScript())
+                    ? \XLite::getCustomerScript()
+                    : \XLite::CART_SELF;
+
+                $url = 'http' . (\Includes\Utils\URLManager::isHTTPS() ? 's' : '') . '://' . $_SERVER['HTTP_HOST']
+                    . (str_replace(['install.php', $customerScript, $adminScript], 'service.php', $_SERVER['PHP_SELF']));
+
+                $curl = curl_init();
+                curl_setopt_array($curl, array(
+                    CURLOPT_RETURNTRANSFER => 1,
+                    CURLOPT_URL => $url,
+                    CURLOPT_HEADER => 1,
+                    CURLOPT_SSL_VERIFYHOST => 0,
+                    CURLOPT_SSL_VERIFYPEER => 0
+                ));
+
+                $resp = curl_exec($curl);
+
+                $result = preg_match('/<div id=app><\/div>/i', $resp);
+
+                curl_close($curl);
+            }
+
+            return [
+                $result,
+                'error_message_1',
+                ['url' => 'https://www.x-cart.com/contact-us.htmlutm_source=XC5Install&amp;utm_medium=reqsFailure&amp;utm_campaign=XC5Install'],
+            ];
+        };
+    }
+
     // }}}
 
     // {{{ Environment
@@ -1546,5 +1551,12 @@ final class Requirements
         }
     }
 
+    /**
+     * @return boolean
+     */
+    private function isMariaDB($version) {
+        return strripos($version, 'MariaDB');
+    }
+
     // }}}
 }
