@@ -219,6 +219,7 @@ function isHardError($code)
             'php_memory_limit',
             'config_file',
             'file_permissions',
+            'frame_options'
         )
     );
 }
@@ -232,9 +233,9 @@ function doCheckRequirements($environment = array())
 {
     $passed = true;
     $result = [];
+    $exclude = [];
 
     $requirements = new \Includes\Requirements($environment);
-    $exclude = [ 'mysql_cache' ];
     foreach ($requirements->getResult($exclude) as $name => $requirement) {
         if ($name === 'install_script') {
             continue;
@@ -273,6 +274,10 @@ function doCheckRequirements($environment = array())
                 break;
             case 'mysql_version':
                 $value = isset($data['version']) ? $data['version'] : '';
+                if ($value && 'unknown' != $value) {
+                    global $params;
+                    $params['mysqlVersion'] = $mysqlVersion = $value;
+                }
                 break;
             case 'php_gdlib':
                 $value = isset($data['version']) ? $data['version'] : '';
@@ -340,7 +345,7 @@ function doPrepareFixtures(&$params, $silentMode = false)
     $result = true;
 
     if (!$silentMode) {
-        echo '<div style="text-align: left; margin-bottom: 20px;">' . xtr('Preparing data for cache generation...');
+        echo '<div class="process-iframe-header">' . xtr('Preparing data for cache generation...');
     }
 
     $enabledModules = array();
@@ -350,7 +355,7 @@ function doPrepareFixtures(&$params, $silentMode = false)
 
         $author = basename($authorDir);
 
-        foreach ((array) glob(LC_DIR_MODULES . $author . '/*/Main.php') as $f) {
+        foreach ((array) glob(LC_DIR_MODULES . $author . '/*/main.yaml') as $f) {
 
             $moduleName = basename(dirname($f));
 
@@ -359,6 +364,10 @@ function doPrepareFixtures(&$params, $silentMode = false)
                 && in_array($moduleName, $lcSettings['enable_modules'][$author])
             );
 
+            if (!$enabledModules[$author][$moduleName]) {
+                continue;
+            }
+
             $dir = 'classes' . LC_DS
                 . 'XLite' . LC_DS
                 . 'Module' . LC_DS
@@ -383,7 +392,8 @@ function doPrepareFixtures(&$params, $silentMode = false)
 
     sort($moduleYamlFiles, SORT_STRING);
 
-    \Includes\Utils\ModulesManager::saveModulesToFile($enabledModules);
+    \Includes\Utils\Module\Manager::getRegistry()->clear();
+    \Includes\Utils\Module\Manager::saveModulesToStorage($enabledModules);
 
     // Generate fixtures list
     $yamlFiles = $lcSettings['yaml_files']['base'];
@@ -464,7 +474,7 @@ function doUpdateMainHtaccess(&$params, $silentMode = false)
     if (!empty($params['xlite_web_dir'])) {
 
         if (!$silentMode) {
-            echo '<br /><b>' . xtr('Updating .htaccess...') . '</b><br>';
+            echo '<div class="process-iframe-header">' . xtr('Updating .htaccess...') . '</div>';
         }
 
         $util = '\Includes\Utils\FileManager';
@@ -629,17 +639,17 @@ function doInstallDirs($silentMode = false)
     }
 
     if ($result && !empty($lcSettings['writable_directories'])) {
-        echo '<div class="section-title">' . xtr('Checking directories permissions...') . '</div>';
+        echo '<div class="iframe-div">' . xtr('Checking directories permissions...') . '</div>';
         chmod_others_directories($lcSettings['writable_directories']);
     }
 
     if (!empty($lcSettings['directories_to_create'])) {
-        echo '<div class="section-title">' . xtr('Creating directories...') . '</div>';
+        echo '<div class="iframe-div">' . xtr('Creating directories...') . '</div>';
         $result = create_dirs($lcSettings['directories_to_create']);
     }
 
     if ($result) {
-        echo '<div class="section-title">Creating directories process is finished</div>';
+        echo '<div class="iframe-div">Creating directories process is finished</div>';
     }
 
     if ($silentMode) {
@@ -742,16 +752,6 @@ function doCreateAdminAccount(&$params, $silentMode = false)
     return $result;
 }
 
-/**
- * Make new safe mode key
- *
- * @return void
- */
-function generate_safe_mode_key()
-{
-    \Includes\SafeMode::regenerateAccessKey(false);
-}
-
 /**
  * Do some final actions
  *
@@ -769,9 +769,7 @@ function doFinishInstallation(&$params, $silentMode = false)
     // Update config settings
     update_config_settings($params);
 
-    update_modules_install_date();
-
-    generate_safe_mode_key();
+    \XLite\Core\Marketplace::getInstance()->setFreshInstall();
 
     // Save authcode for the further install runs
     $authcode = save_authcode($params);
@@ -825,13 +823,12 @@ function doFinishInstallation(&$params, $silentMode = false)
 
             $permsHTML =<<<OUT
 
-<div class="field-label">{$permsTitle}</div>
+<div>{$permsTitle}</div>
 
 <ul class="permissions-list">
 $perms
 </ul>
 
-<br />
 <div class="clipbrd">
   <input type="button" class="btn btn-default copy2clipboard" value="{$copyText}" />
   <div class="copy2clipboard-alert alert-success" style="display: none;"></div>
@@ -855,7 +852,7 @@ OUT;
             ':perms'        => $perms_no_tags,
             ':renametext'   => $install_rename_email,
             ':authcode'     => $authcode,
-            ':safekey'      => \Includes\SafeMode::getAccessKey(),
+            ':safekey'      => '',
         )
     );
 
@@ -874,13 +871,9 @@ OUT;
   document.cookie = 'passed_steps=; expires=-1';
 </script>
 
-<br />
-<br />
-
 <?php echo $permsHTML; ?>
-<?php x_install_check_step_seven_requirements($params); ?>
 
-<div class="field-label second-title"><?php echo xtr('X-Cart software has been successfully installed and is now available at the following URLs:'); ?></div>
+<div class="second-title"><?php echo xtr('X-Cart software has been successfully installed and is now available at the following URLs:'); ?></div>
 
 <p class="customer-link"><a href="cart.php" class="final-link" target="_blank"><?php echo xtr('Customer zone (front-end)'); ?></a></p>
 
@@ -913,47 +906,6 @@ OUT;
     return $result;
 }
 
-function x_install_check_step_seven_requirements($params)
-{
-    $requirements = new \Includes\Requirements($params);
-
-    $requirement = $requirements->getSingleResult('mysql_cache');
-    $status = $requirement['state'] === \Includes\Requirements::STATE_SUCCESS;
-
-    $value = '';
-
-    $resultRequirement = [
-        'title' => xtr($requirement['title']),
-        'status' => $status,
-        'critical' => $requirement['level'] === \Includes\Requirements::LEVEL_CRITICAL,
-        'value' => $value,
-        'data' => $requirement['data'],
-    ];
-
-    $messageData = [];
-    foreach ($requirement['data'] as $varName => $varValue) {
-        if (is_scalar($varValue)) {
-            $messageData[':' . $varName] = $varValue;
-        }
-    }
-    $resultRequirement['messageData'] = $messageData;
-
-    $resultRequirement['description'] = $status ? '' : xtr('mysql_cache.' . $requirement['description'], $messageData);
-
-    if ($requirement['state'] === \Includes\Requirements::STATE_SKIPPED) {
-        $resultRequirement['skipped'] = true;
-    }
-    if (!$status
-        && !$resultRequirement['status']
-        && isset($resultRequirement['description'])
-    ) {
-        echo sprintf(
-           '<p><strong>%s:</strong> %s</p>',
-            xtr('Warning'), $resultRequirement['description']
-        );
-    }
-}
-
 /*
  * Service functions section
  */
@@ -1213,6 +1165,7 @@ function change_config(&$params)
         'username'     => 'mysqluser',
         'password'     => 'mysqlpass',
         'table_prefix' => 'mysqlprefix',
+        'charset'      => 'mysqlcharset',
         'port'         => 'mysqlport',
         'socket'       => 'mysqlsock',
         'http_host'    => 'xlite_http_host',
@@ -1270,6 +1223,18 @@ function change_config(&$params)
         $patterns[] = '/^default = [a-z]{2}/';
         $replacements[] = 'default = ' . XLITE_EDITION_LNG;
 
+        $patterns[] = '/^product_clean_urls_format.*=.*/';
+        $replacements[] = 'product_clean_urls_format = ' . 'domain/goalproduct';
+
+        $patterns[] = '/^static_page_clean_urls_format.*=.*/';
+        $replacements[] = 'static_page_clean_urls_format = ' . 'domain/goalpage';
+
+        $patterns[] = '/^vendor_clean_urls_format.*=.*/';
+        $replacements[] = 'vendor_clean_urls_format = ' . 'domain/goalvendor';
+
+        $patterns[] = '/^news_clean_urls_format.*=.*/';
+        $replacements[] = 'news_clean_urls_format = ' . 'domain/goalnews';
+
         // escape every backslash and dollar sign with a backslash
         // to avoid using them as backreferences
         $replacements = array_map(function ($replacement) {
@@ -1505,9 +1470,7 @@ function make_check_report($requirements)
 
     foreach ($requirements as $reqName => $reqData) {
 
-        if (($reqName === 'mysql_version' && $reqData['data']['version'] === 'unknown')
-            || ($reqName === 'mysql_cache' && $reqData['data']['query_cache_type'] === 'unknown')
-        ) {
+        if ($reqName === 'mysql_version' && $reqData['data']['version'] === 'unknown') {
             continue;
         }
 
@@ -1733,7 +1696,7 @@ function fatal_error_extended($txt, $errorCategory, $errorCode, $additionalNote
 }
 
 /**
- * Display block 'Consider hosting your X-Cart with us...'
+ * Display block 'Create Online Store with X‑Cart...'
  *
  * @param boolean $hidden Flag: is block should be hidden (true) or visible (false)
  *
@@ -1756,16 +1719,16 @@ function x_display_help_block($hidden = true)
 
     <?php x_display_hosting_icon(); ?>
 
-    <div class="cloud-header"><?php echo xtr('Consider hosting your X-Cart with us'); ?></div>
-    <div class="cloud-text"><?php echo xtr('VPS hosting for X-Cart. No installation hassle. Fully customizable.'); ?></div>
+    <div class="cloud-header"><?php echo xtr('Create Online Store with X‑Cart!'); ?></div>
+    <div class="cloud-text"><?php echo xtr('No limitations or transaction fees, Open source code for easy customization, Great 24/7 support'); ?></div>
 
 <?php if ($hidden) { ?>
 
-    <a href="<?php echo $url; ?>" target="_blank"><?php echo xtr('Create an online store for free'); ?></a>
+    <a href="<?php echo $url; ?>" target="_blank"><?php echo xtr('Get first 30 days for FREE'); ?></a>
 
 <?php } else { ?>
 
-  <input type="button" id="create-online-store" class="btn btn-default btn-lg" value="<?php echo xtr('Create an online store for free'); ?>" onclick="javascript:window.open('<?php echo $url; ?>');" />
+  <input type="button" id="create-online-store" class="btn btn-default btn-lg" value="<?php echo xtr('Get first 30 days for FREE'); ?>" onclick="javascript:window.open('<?php echo $url; ?>');" />
 
 <?php } ?>
 
@@ -1919,7 +1882,7 @@ function default_js_next()
 function generate_authcode()
 {
     // see include/functions.php
-    return generate_code();
+    return generate_code(32);
 }
 
 /**
@@ -1931,6 +1894,8 @@ function generate_authcode()
  */
 function check_authcode(&$params)
 {
+    global $error;
+
     $authcode = get_authcode();
 
     // if authcode IS NULL, then this is probably the first install, skip
@@ -1940,8 +1905,8 @@ function check_authcode(&$params)
     }
 
     if (!isset($params['auth_code']) || trim($params['auth_code']) != $authcode) {
-        warning_error(xtr('Incorrect auth code! You cannot proceed with the installation.'), 'auth code');
-        exit();
+        fatal_error(xtr('Incorrect auth code! You cannot proceed with the installation.'), 'auth code', 'incorrect auth code');
+        $error = true;
     }
 }
 
@@ -1952,8 +1917,11 @@ function check_authcode(&$params)
  */
 function get_authcode()
 {
+    global $error;
+
     if (!$data = parse_config()) {
         fatal_error(xtr('Config file not found (:filename)', array(':filename' => constant('LC_CONFIG_FILE'))), 'file', 'config file not found');
+        $error = true;
     }
 
     return !empty($data['auth_code']) ? $data['auth_code'] : null;
@@ -2002,8 +1970,6 @@ function update_config_settings($params)
 
     $time = \XLite\Core\Converter::time();
 
-    $poweredBy = \XLite\View\PoweredBy::getPoweredByPhraseIndex();
-
     $serializedSiteEmail = serialize([$siteEmail]);
     $options = array(
         'Company::orders_department'  => $serializedSiteEmail,
@@ -2014,7 +1980,6 @@ function update_config_settings($params)
         'Company::start_year'         => date('Y', $time),
         'Version::timestamp'          => $time,
         'CleanURL::clean_url_flag'    => inst_http_request_clean_urls(),
-        'Internal::prnotice_index'    => $poweredBy,
     );
 
     if (!$options['CleanURL::clean_url_flag']) {
@@ -2045,17 +2010,6 @@ function update_config_settings($params)
     \XLite\Core\Database::getEM()->flush();
 }
 
-function update_modules_install_date() {
-    $qb = \XLite\Core\Database::getRepo('XLite\Model\Module')
-        ->createQueryBuilder();
-
-    $qb->update()
-        ->set("{$qb->getMainAlias()}.date", ':time')
-        ->setParameter('time', \XLite\Core\Converter::time())
-        ->getQuery()
-        ->execute();
-}
-
 /**
  * Save Auth code
  *
@@ -2160,11 +2114,10 @@ function getTimeZones($addBlank = false)
  *
  * @param string $fieldName
  * @param array  $fieldData
- * @param int    $clrNumber
  *
  * @return string
  */
-function displayFormElement($fieldName, $fieldData, $clrNumber)
+function displayFormElement($fieldName, $fieldData)
 {
     global $currentSection;
 
@@ -2246,16 +2199,20 @@ OUT;
         if (!empty($currentSection)) {
             $output .=<<<OUT
     <tr class="section-title section-{$currentSection}">
-        <td colspan="2"><span onclick="javascript: toggleSection('{$currentSection}');">{$sections[$currentSection]}</span></td>
+        <td><span onclick="javascript: toggleSection('{$currentSection}');">{$sections[$currentSection]}</span></td>
     </tr>
 OUT;
         }
     }
 
+    $notice = $fieldData["description"]
+        ? "<div class='field-notice'>{$fieldData['description']}</div>"
+        : "";
+
     $output .=<<<OUT
-    <tr class="color-{$clrNumber} {$sectionCSS}">
-        <td class="table-left-column"><div class="field-label">{$fieldData['title']}{$requiredField}</div><div class="field-notice">{$fieldData['description']}</div></td>
-        <td class="table-right-column">{$formElement}</td>
+    <tr class="{$sectionCSS}">
+        <td class="table-left-column"><div class="field-label">{$fieldData['title']}{$requiredField}</div></td>
+        <td class="table-right-column">{$formElement}{$notice}</td>
     </tr>
 OUT;
 
@@ -2344,24 +2301,17 @@ function module_check_cfg(&$params)
     $errorsFound = false;
     $warningsFound = false;
 
-    $sections = array(
+    $sections = [
         'A' => xtr('Environment checking'),
         'B' => xtr('Inspecting server configuration'),
-    );
+    ];
 
-    $steps = array(
-        /*1 => array(
-            'title'        => xtr('Environment'),
-            'error_msg'    => xtr('Environment checking failed'),
-            'section'      => 'A',
-            'requirements' => array(
-            )
-        ),*/
-        2 => array(
+    $steps = [
+        [
             'title'        => xtr('Critical dependencies'),
             'error_msg'    => xtr('Critical dependency failed'),
             'section'      => 'B',
-            'requirements' => array(
+            'requirements' => [
                 'php_version',
                 'php_memory_limit',
                 'doc_blocks_support',
@@ -2369,23 +2319,24 @@ function module_check_cfg(&$params)
                 'config_file',
                 'file_permissions',
                 'frame_options'
-            )
-        ),
-        3 => array(
+            ]
+        ],
+        [
             'title'        => xtr('Non-critical dependencies'),
             'error_msg'    => xtr('Non-critical dependency failed'),
             'section'      => 'B',
-            'requirements' => array(
+            'requirements' => [
                 'php_disabled_functions',
                 'php_file_uploads',
                 'php_upload_max_file_size',
                 'php_gdlib',
                 'php_phar',
                 'https_bouncer',
-                'xml_support'
-            )
-        )
-    );
+                'xml_support',
+                'loopback_request'
+            ]
+        ]
+    ];
 
     ob_start();
     require_once LC_DIR_ROOT . 'Includes/install/templates/step1_chkconfig.tpl.php';
@@ -2423,6 +2374,7 @@ function applySuggestedDefValues(&$paramFields)
     $paramFields['mysqlport']['def_value'] = ini_get('mysqli.default_port') ?: (ini_get('mysql.default_port') ?: '');
     $paramFields['mysqlsock']['def_value'] = ini_get('pdo_mysql.default_socket') ?: (ini_get('mysqli.default_socket') ?: (ini_get('mysql.default_socket') ?: ''));
     $paramFields['mysqlprefix']['def_value'] = 'xc_';
+    $paramFields['mysqlcharset']['def_value'] = 'utf8mb4';
 
     $paramFields['demo']['def_value'] = '1';
 
@@ -2450,8 +2402,6 @@ function module_cfg_install_db(&$params)
     $pdoErrorMsg = '';
     $output = '';
 
-    $clrNumber = 1;
-
     $requirements = doCheckRequirements();
 
     // Remove report file if it was created on the previous step
@@ -2468,7 +2418,7 @@ function module_cfg_install_db(&$params)
         ),
         'mysqlbase'        => array(
             'title'       => xtr('MySQL database name'),
-            'description' => xtr('The name of the existing database to use (if the database does not exist on the server, you should create it to continue the installation).'),
+            'description' => xtr('Name of a new or existing database to use.'),
             'required'    => true,
         ),
         'mysqluser'        => array(
@@ -2508,6 +2458,14 @@ function module_cfg_install_db(&$params)
             'required'    => true,
             'section'     => 'advanced-mysql',
         ),
+        'mysqlcharset'       => array(
+            'title'       => xtr('Default charset'),
+            'description' => '',
+            'select_data' => ['utf8mb4' => 'utf8mb4', 'utf8' => 'utf8'],
+            'required'    => false,
+            'type'        => 'select',
+            'section'     => 'advanced-mysql',
+        ),
         'xlite_http_host'  => array(
             'title'       => xtr('Web server name'),
             'description' => xtr('Hostname of your web server (E.g.: www.example.com).'),
@@ -2539,6 +2497,11 @@ function module_cfg_install_db(&$params)
     // Initialize default values for parameters
     applySuggestedDefValues($paramFields);
 
+    if ($requirements['loopback_request']['status'] === false) {
+        unset($paramFields['demo']);
+        $params['demo'] = 'Y';
+    }
+
     $messageText = '';
 
     $displayConfigForm = false;
@@ -2581,8 +2544,7 @@ function module_cfg_install_db(&$params)
 
             $fieldData['value'] = (isset($params[$fieldName]) ? $params[$fieldName] : $fieldData['def_value']);
 
-            displayFormElement($fieldName, $fieldData, $clrNumber);
-            $clrNumber = ($clrNumber == 2) ? 1 : 2;
+            displayFormElement($fieldName, $fieldData);
         }
 
         $output = ob_get_contents();
@@ -2696,15 +2658,6 @@ function module_cfg_install_db(&$params)
                     $checkError = true;
                 }
 
-                if (!$checkError
-                    && isset($requirements['mysql_cache'])
-                    && $requirements['mysql_cache']
-                    && !$requirements['mysql_cache']['status']
-                ) {
-                    warning_error($requirements['mysql_cache']['description'], 'reqs');
-                    $checkWarning = true;
-                }
-
                 // Check if config.php file is writeable
                 if (!$checkError && !@is_writable(LC_DIR_CONFIG . constant('LC_CONFIG_FILE'))) {
                     fatal_error(xtr('Cannot open file \':filename\' for writing. To install the software, please correct the problem and start the installation again...', array(':filename' => constant('LC_CONFIG_FILE'))), 'file', 'config write failed');
@@ -2876,7 +2829,7 @@ function module_cfg_install_db_js_next()
  */
 function module_install_cache(&$params, $silentMode = false)
 {
-    global $error;
+    global $error, $lcSettings;
 
     $result = false;
 
@@ -2916,6 +2869,9 @@ function module_install_cache(&$params, $silentMode = false)
                     $sql = str_replace('`FK_',  '`FK_'  . $randPrefix, $sql);
                     $sql = str_replace('`IDX_', '`IDX_' . $randPrefix, $sql);
 
+                    if ($params['mysqlcharset'] !== 'utf8') {
+                        $sql = str_replace('utf8', $params['mysqlcharset'], $sql);
+                    }
 
                     // Load SQL dump to the database
                     $pdoErrorMsg = '';
@@ -2985,17 +2941,18 @@ setTimeout('isProcessComplete()', 1000);
 
             doRemoveCache(null);
 
+            $enabledModules = json_encode($lcSettings['enable_modules']);
 ?>
 
 <div id="cache-rebuild-failed" class="cache-error" style="display: none;"><span><?php echo xtr('Oops!'); ?></span> <?php echo xtr('The current step of the cache rebuilding process is taking longer than expected. Check for possible problems <a href="https://kb.x-cart.com/pages/viewpage.action?pageId=7504578" target="_blank">here</a>.'); ?></div>
 
-<iframe id="process_iframe" style="padding-top: 15px;" src="admin.php?doNotRedirectAfterCacheIsBuilt&<?php echo time(); ?>" width="100%" height="300" frameborder="0" marginheight="10" marginwidth="10"></iframe>
+<?php
+$params['auth_code'] = $params['auth_code'] ? $params['auth_code'] : save_authcode($params);
+?>
 
-<br />
-<br />
-<br />
+<iframe id="process_iframe" src="service.php?/install&<?php echo http_build_query(['modules' => $enabledModules, 'version' => LC_VERSION, 'auth_code' => $params['auth_code']]); ?>" width="100%" height="300" frameborder="0" marginheight="10" marginwidth="10"></iframe>
 
-<?php echo xtr('Building cache notice'); ?>
+<?php echo '<div class="building-cache-notice">' . xtr('Building cache notice') . '</div>'; ?>
 
 <script type="text/javascript">
 
@@ -3010,19 +2967,20 @@ setTimeout('isProcessComplete()', 1000);
         if (iframe.getElementById('finish')) {
             resetCacheWindowContent();
 
-        } else {
+        } else if (iframe.body.innerHTML) {
+            var finishedStepsCount = iframe.getElementsByClassName('finished-step-info').length;
 
-            var pattern = /^.*Deploying store \[step (\d+) of (\d+)\].*$/m;
-            var matches = iframe.body.innerHTML.match(pattern);
-
-            if (matches && currentStep !== matches[1]) {
-               errCount = 0;
-               currentStep = matches[1];
-               resetCacheRebuildFailure();
+            if (currentStep !== finishedStepsCount) {
+                errCount = 0;
+                currentStep = finishedStepsCount;
+                resetCacheRebuildFailure();
             }
 
             if (errCount > 60) {
-                processCacheRebuildFailure(matches);
+                var currentStepInfo = iframe.querySelector('.in-progress-step-info div')
+                    ? iframe.querySelector('.in-progress-step-info div').innerHTML
+                    : '';
+                processCacheRebuildFailure(currentStepInfo);
                 isStopped = true;
 
             } else {
@@ -3030,6 +2988,9 @@ setTimeout('isProcessComplete()', 1000);
             }
 
             setTimeout('isProcessComplete()', 1000);
+
+        } else {
+            setTimeout('isProcessComplete()', 1000);
         }
     }
 
@@ -3139,18 +3100,11 @@ function module_cfg_create_admin(&$params)
         ),
     );
 
-    $clrNumber = 1;
-
 ?>
 
 <div>
 
-<div class="field-left">
-
-<?php echo xtr('E-mail and password that you provide on this screen will be used to create primary administrator profile. Use them as credentials to access the Administrator Zone of your online store.'); ?>
-
-<br />
-<br />
+<p class="text-left"><?php echo xtr('E-mail and password that you provide on this screen will be used to create primary administrator profile. Use them as credentials to access the Administrator Zone of your online store.'); ?></p>
 
 <table width="100%" border="0" cellpadding="10">
 
@@ -3158,8 +3112,7 @@ function module_cfg_create_admin(&$params)
 
 
     foreach ($paramFields as $fieldName => $fieldData) {
-        displayFormElement($fieldName, $fieldData, $clrNumber);
-        $clrNumber = ($clrNumber == 2) ? 1 : 2;
+        displayFormElement($fieldName, $fieldData);
     }
 
 ?>
@@ -3168,14 +3121,6 @@ function module_cfg_create_admin(&$params)
 
 </div>
 
-<div class="field-right">
-
-    <img class="keyhole-icon" src="<?php echo $skinsDir; ?>images/keyhole_icon.png" alt="" />
-
-</div>
-
-</div>
-
 <div class="clear"></div>
 
 <?php
