@@ -45,7 +45,7 @@ foreach ($filesToInclude as $_file) {
         die('Fatal error: Couldn\'t find file ' . $includeFuncsFile);
     }
 
-    include_once $includeFuncsFile;
+    require_once $includeFuncsFile;
 }
 
 
@@ -158,7 +158,7 @@ if (isset($_GET['target']) && $_GET['target'] == 'install') {
     setTimeout('refresh()', 1000);
 </script>
 
-<body style="padding-top: 20px;">
+<body>
 
 <?php
 
@@ -266,6 +266,7 @@ show_install_css();
 ?>
 
 <script src="skins/common/js/jquery.min.js"></script>
+<script src="skins/common/js/jquery-migrate.js"></script>
 <script src="skins/common/bootstrap/js/bootstrap.min.js"></script>
 <script src="skins/common/js/clipboard.min.js"></script>
 
@@ -375,23 +376,17 @@ function resetCacheWindowContent()
 	document.getElementById('process_iframe').contentWindow.document.write(content);
 }
 
-function processCacheRebuildFailure(stepData)
+function processCacheRebuildFailure(currentStepInfo)
 {
     document.getElementById('cache-rebuild-failed').style.display = '';
     document.getElementById('process_iframe').style.borderColor = '#c11600';
 
     if (!isStopped) {
-        var step = '';
-
-        if (stepData[1] && stepData[2]) {
-            step = stepData[1] + ' of ' + stepData[2]
-        }
-
-        ga('send', 'event', 'error', 'cache', 'cache deployment failed (' + step + ')');
+        ga('send', 'event', 'error', 'cache', 'cache deployment failed (' + currentStepInfo + ')');
     }
 }
 
-function resetCacheRebuildFailure(stepData)
+function resetCacheRebuildFailure()
 {
   document.getElementById('cache-rebuild-failed').style.display = 'none';
   document.getElementById('process_iframe').style.borderColor = 'black';
@@ -514,7 +509,6 @@ foreach ($rows as $row) {
   </div>
 
   <div class="install-help-box">
-    <img src="skins/admin/images/icon-install-help.svg" />
     <div>
       <?php echo xtr('Having trouble installing X-Cart? Check out our installation guide'); ?>
     </div>
@@ -550,13 +544,10 @@ if ($modules[$current]['auth_required']) {
 }
 
 // run module
-$res = $func($params);
+$res = $error ? false : $func($params);
 
 ?>
 
-<br />
-<br />
-
 <?php
 
 // show navigation buttons
