@@ -53,13 +53,15 @@ $translation = array (
   'Recursion test failed.' => 'Recursion test failed.',
   'unknown' => 'unknown',
   'Can\'t connect to MySQL server' => 'Cannot connect to MySQL server',
-  'mysql_version.error_message_1' => 'MySQL version must be at least :minMysqlVersion.',
+  'mysql_version.error_message_1' => ':rdbms version must be at least :minMysqlVersion.',
   'mysql_version.error_message_3' => 'Cannot get MySQL server version (:error).',
   'php_gdlib.error_message_1' => 'GDlib extension v.2.0 or later is required for some modules.',
   'Phar extension is not loaded' => 'Phar extension not loaded',
   'https_bouncer.error_message_2' => 'libcurl extension not found.',
   'https_bouncer.error_message_1' => 'libcurl extension is found but does not support secure protocols.',
   'xml_support.error_message_1' => 'XML/Expat and DOM extensions are required for some modules.',
+  'loopback_request.label_message' => 'My Addons (service.php) is not available, please <a href="https://www.x-cart.com/contact-us.htmlutm_source=XC5Install&amp;utm_medium=reqsFailure&amp;utm_campaign=XC5Install">contact us</a>',
+  'loopback_request.error_message_1' => 'My Addons (service.php) is not available, please <a href="https://www.x-cart.com/contact-us.htmlutm_source=XC5Install&amp;utm_medium=reqsFailure&amp;utm_campaign=XC5Install">contact us</a>',
   'config_writing_error' => 'Cannot open configuration file \':configfile\' for writing. This unexpected error has cancelled the installation. To install the software, please correct the problem and start the installation again.',
   'mysql_connection_error' => 'Cannot connect to MySQL server:pdoerr.<br />This unexpected error has cancelled the installation. To install the software, please correct the problem and start the installation again.',
   'doDropDatabaseTables() failed' => 'doDropDatabaseTables() failed',
@@ -86,7 +88,7 @@ Should you decide to re-install X-Cart, remember to rename  file ":newname" back
 To ensure safety of your X-Cart installation, file "install.php" has been renamed to ":newname".<br />
 Should you decide to re-install X-Cart, remember to rename file ":newname" back to "install.php"
 ',
-  'script_cannot_be_renamed_text' => '<span style="color: red;"><b>WARNING!</b> The install.php script could not be renamed! To ensure safety of your X-Cart installation and prevent unauthorized use of this script, rename or delete the script manually.</span>',
+  'script_cannot_be_renamed_text' => '<span style="color: #a94461;"><b>WARNING!</b> The install.php script could not be renamed! To ensure safety of your X-Cart installation and prevent unauthorized use of this script, rename or delete the script manually.</span>',
   'correct_permissions_text' => 'Before you start using your X-Cart shopping system, please set the following secure file permissions:',
   'congratulations_text' => '
 Congratulations!
@@ -165,7 +167,7 @@ X-Cart Installation Wizard
   'MySQL server socket' => 'MySQL server socket',
   'If your database server is used a non-standard socket, specify it (e.g. /tmp/mysql-5.1.34.sock).' => 'If your database server uses a non-standard socket, specify it here (e.g. /tmp/mysql-5.1.34.sock).',
   'MySQL database name' => 'MySQL database name',
-  'The name of the existing database to use (if the database does not exist on the server, you should create it to continue the installation).' => 'Name of an existing database to use (if the database does not exist on the server, the installation script will try to create it).',
+  'Name of a new or existing database to use.' => 'Name of a new or existing database to use.',
   'MySQL username' => 'MySQL username',
   'MySQL username. The user must have full access to the database specified above.' => 'MySQL username. The user must have unrestricted access to the database specified above.',
   'MySQL password' => 'MySQL password',
@@ -238,7 +240,7 @@ X-Cart Installation Wizard
   'Prevents unauthorized use of installation script' => 'Prevents unauthorized use<br />of the installation script',
   'I accept the License Agreement' => 'I accept the License Agreement and the <a href="https://www.x-cart.com/privacy-policy.html?utm_source=XC5Install&utm_medium=acceptLA&utm_campaign=XC5Install" target="_blank">Privacy policy</a>',
   'Could not find license agreement file.<br />Aborting installation.' => 'Could not find the license agreement file.<br />Aborting installation.',
-  'php_version.label_message' => 'PHP versions <b>5.4.0+</b> are currently supported.',
+  'php_version.label_message' => 'PHP versions <b>:minPhpVersion+</b> are currently supported.',
   'php_disabled_functions.label_message' => 'Some functions, used by X-Cart, are found disabled. Make sure that these functions are not listed in "disable_functions" option and all php extensions required for these functions availability are enabled in the php.ini file. Please correct this and try again.',
   'php_memory_limit.label_message' => 'PHP memory_limit option must be at least :memoryLimitMin.',
   'php_pdo_mysql.label_message' => 'PDO extension with enabled MySQL support is used by X-Cart for connecting to the database. Please make sure this extension is loaded in your php.ini file and try again.',
@@ -247,7 +249,7 @@ X-Cart Installation Wizard
   'php_gdlib.label_message' => 'GDLib 2.0 or better is required for automatic generation of product thumbnails form product images and for some other modules. GDLib must be compiled with libJpeg (ensure that PHP is configured with option --with-jpeg-dir=DIR, where DIR is the directory where libJpeg is installed). Please contact the support services of your hosting provider to have the parameter adjusted.',
   'php_phar.label_message' => 'Phar extension is required for installation of external X-Cart addons and upgrades from the Marketplace.  Phar v.2.0.1 or later is recommended, otherwise this features may fail to work properly. Please contact your hosting provider\'s support to have this parameter adjusted.',
   'https_bouncer.label_message' => 'The libCURL module with HTTPS protocol support and a valid SSL certificate is required for credit cards processing via Authorize.NET, PayPal or other payment gateways and using real-time shipping calculation services (these services require your website to accept secure connections via HTTPS/SSL). Please contact your hosting provider\'s support to have these parameters adjusted.',
-  'xml_support.label_message' => 'Xml/EXPAT and DOMDocument extensions for PHP are required for using real-time shipping modules and payment modules. Please contact your hosting provider\'s support to have these parameters adjusted.',
+  'xml_support.label_message' => 'Xml/EXPAT and DOMDocument extensions for PHP are required for real-time shipping modules, payment modules and email notifications. Please contact your hosting provider to have these extensions enabled.',
   'DocBlocks support' => 'DocBlocks support',
   'doc_blocks_support.error_message_1' => 'The DocBlock feature is not supported by your PHP. This feature is required for X-Cart operation.',
   'doc_blocks_support.error_message_2' => 'The DocBlock feature is not supported by your PHP. This feature is required for X-Cart operation. The cause of DocBlock feature being blocked may be the eAccelerator extension. Disable this extension and try again.',
@@ -279,15 +281,14 @@ X-Cart Installation Wizard
   'Strong' => 'Strong',
   'Uploading dump.sql into database...' => 'Uploading SQL dump into database...',
   'Redirecting to the next step...' => 'Redirecting to the next step...',
-  'Create an online store for free' => 'Create an online store for free',
-  'Consider hosting your X-Cart with us' => 'Consider hosting your X-Cart with us',
-  'VPS hosting for X-Cart. No installation hassle. Fully customizable.' => 'VPS hosting for X-Cart. No installation hassle.<br />Fully customizable.',
+  'Get first 30 days for FREE' => 'Get first 30 days for FREE',
+  'Create Online Store with X‑Cart!' => 'Create Online Store with X‑Cart!',
+  'No limitations or transaction fees, Open source code for easy customization, Great 24/7 support' => 'No limitations or transaction fees, Open source code for easy customization, Great 24/7 support',
   'Having trouble installing X-Cart? Check out our installation guide' => 'Having trouble installing X-Cart?<br />Check out our <a href="https://kb.x-cart.com/en/general_setup/installation_guide.html" target="_blank">installation guide</a>',
   'X-Cart can track and store user actions to improve the UI/UX and merchant experience. You can stop user action tracking at any time by removing the Concierge module.' => 'X-Cart can track and store user actions to improve the UI/UX and merchant experience. You can stop user action tracking at any time by removing the Concierge module.',
   'config_file.error_message_1' => 'Config file does not exist and cannot be copied from the default config file. It is required for the installation.<br /><br />Please, follow these steps: <br /><br />1. Go to directory :configPath<br />2. Copy <i>:defaultConfigFileName</i> to <i>:configFileName</i><br />3. Set writeable permissions on <i>:configFileName</i><br /><br />Then try again.',
   'php_disabled_functions.error_message_1' => 'The following functions are disabled:<br/>:missedFunctions<br/>These functions may be used by the software in some cases and should be enabled.',
   'mysql_version.error_message_2' => 'InnoDB engine is not supported by MySQL server. InnoDB is required for X-Cart operation.',
-  'mysql_cache.error_message_1' => 'MySQL query cache is not enabled. See <a href="https://dev.mysql.com/doc/refman/5.7/en/query-cache-configuration.html" target="_blank">https://dev.mysql.com/doc/refman/5.7/en/query-cache-configuration.html</a> for how to enable it.',
   'php_gdlib.error_message_2' => 'GDlib extension does not have the JPEG plugin.',
   'php_phar.error_message_1' => 'Phar extension v.2.0.1 or later is required to get upgrades and install modules; otherwise, these features may not work properly.',
   'frame_options.error_message_1' => 'Your server X-Frame-Options header is configured to DENY. This option is required to be set to SAMEORIGIN or ALLOW-FROM xcart_host for X-Cart installation process. You can set it back to DENY after X-Cart is installed.',
