@@ -54,7 +54,7 @@ $translation = array (
   'Recursion test failed.' => 'Проверка рекурсии не выполнена',
   'unknown' => 'не известно',
   'Can\'t connect to MySQL server' => 'Нет соединения с MySQL сервером',
-  'mysql_version.error_message_1' => 'Версия MySQL должна быть как минимум :minMysqlVersion.',
+  'mysql_version.error_message_1' => 'Версия :rdbms должна быть как минимум :minMysqlVersion.',
   'mysql_version.error_message_3' => 'Не удалось определить версию MySQL сервера (:error).',
   'php_gdlib.error_message_1' => 'Для некоторых модулей необходимо расширение GDlib версии 2.0 или выше.',
   'Phar extension is not loaded' => 'Расширение Phar не загружено',
@@ -162,7 +162,7 @@ $translation = array (
   'MySQL server socket' => 'Сокет MySQL сервера',
   'If your database server is used a non-standard socket, specify it (e.g. /tmp/mysql-5.1.34.sock).' => 'Если ваш сервер базы использует нестандартный сокет, укажите его здесь (напр., /tmp/mysql-5.1.34.sock).',
   'MySQL database name' => 'Имя MySQL базы данных',
-  'The name of the existing database to use (if the database does not exist on the server, you should create it to continue the installation).' => 'Имя готовой базы данных, которая будет использована. Если база данных не существует на сервере, скрипт установки попытается создать ее.',
+  'Name of a new or existing database to use.' => 'Имя новой или существующей базы данных.',
   'MySQL username' => 'Имя пользователя MySQL',
   'MySQL username. The user must have full access to the database specified above.' => 'Имя пользователя MySQL. Пользователь должен иметь полный доступ к вышеобозначенной базе данных.',
   'MySQL password' => 'MySQL пароль',
@@ -217,7 +217,7 @@ $translation = array (
   'Status' => 'Статус',
   'Non-critical dependency failed' => 'Рекомендованные библиотеки или программное обеспечение не найдено',
   'requirements_failed_text' => 'Пожалуйста, обратитесь к своему <em>провайдеру хостинга</em> или отправьте нам <em>сведения об ошибке установки</em>, и наши специалисты помогут вам найти решение.',
-  'Send a report' => 'Отправить сведения об ошибках',
+  'Send a report' => 'Техподдержка',
   'Send report and get a help' => 'Отправить отчет и получить помощь',
   'requirement_warning_text' => 'Конфигурация сервера неблагоприятна для установки. Это может привести к частичной или полной неработоспособности магазина X‑Cart 5. <br />Продолжить установку все равно?',
   'Yes, I want to continue the installation.' => 'Да, я хочу продолжить установку.',
@@ -233,7 +233,7 @@ $translation = array (
   'Prevents unauthorized use of installation script' => 'Предотвращает неавторизованное использование<br />скрипта установки',
   'I accept the License Agreement' => 'Я принимаю условия соглашения и <a href="https://www.x-cart.ru/privacy-policy.html?utm_source=XC5Install&amp;utm_medium=acceptLA&amp;utm_campaign=XC5Install" target="_blank">Правила соблюдения конфиденциальности</a>',
   'Could not find license agreement file.<br />Aborting installation.' => 'Файл лицензионного соглашения не найден.<br />Прекращение установки.',
-  'php_version.label_message' => 'Версии PHP <b>5.4.0+</b> поддерживаются.',
+  'php_version.label_message' => 'Версии PHP <b>:minPhpVersion+</b> поддерживаются.',
   'php_disabled_functions.label_message' => 'Обнаружено, что некоторые функции, используемые X‑Cart 5, отключены. Убедитесь, что эти функции не упомянуты в опции "disable_functions", и все php-расширения, необходимые для работы этих функций, активированы в файле php.ini. Пожалуйста, устраните проблему и попробуйте снова.',
   'php_memory_limit.label_message' => 'Значение PHP опции memory_limit должно быть как минимум :memoryLimitMin.',
   'php_pdo_mysql.label_message' => 'При поддержке MySQL,  расширение PDO необходимо для подключения X‑Cart 5 к базе данных. Пожалуйста, убедитесь, что это расширение включено в файле php.ini, и попробуйте еще раз.',
@@ -242,7 +242,9 @@ $translation = array (
   'php_gdlib.label_message' => 'GDLib версии 2.0 или выше требуется для автоматической генерации уменьшенных изображений товаров из изображений товаров и для некоторых других модулей. Библиотека GDLib должна включать libJpeg (убедитесь, что сконфигурирована PHP опция  --with-jpeg-dir=DIR, где DIR - это директория установки libJpeg). Пожалуйста, обратитесь в поддержку своего хостинг-провайдера для настройки этого параметра.',
   'php_phar.label_message' => 'Расширение Phar необходимо для установки внешних модулей для X‑Cart 5 и обновлений с Маркетплейса. Рекомендуется использовать Phar версии 2.0.1 или новее, иначе, возможен сбой в работе. Пожалуйста, обратитесь в поддержку своего хостинг-провайдера для настройки данного параметра.',
   'https_bouncer.label_message' => 'Поддержка безопасного протокола HTTPS, наличии действующего SSL-сертификата и модуль LibCURL необходимы для обработки кредитных карт через Authorize.NET, PayPal и другие платежные системы, предоставляющие услуги расчета стоимости доставки в режиме реального времени (для этого ваш сайт должен воспринимать безопасное подключение посредством HTTPS/SSL). Пожалуйста, обратитесь в техподдержку своего хостинг-провайдера для настройки данных параметров.',
-  'xml_support.label_message' => 'PHP расширения Xml/EXPAT и DOMDocument необходимы для работы модулей, предоставляющих возможность расчета стоимости доставки в режиме реального времени, а также, для платежных модулей. Пожалуйста, обратитесь в техподдержку своего хостинг-провайдера для настройки данных параметров.',
+  'xml_support.label_message' => 'PHP расширения Xml/EXPAT и DOMDocument необходимы для работы модулей, предоставляющих возможность расчета стоимости доставки в режиме реального времени, а также, для платежных модулей и корректной работы e-mail уведомлений. Пожалуйста, обратитесь в техподдержку своего хостинг-провайдера для настройки данных параметров.',
+  'loopback_request.label_message' => 'Страница Мои Приложения (service.php) не доступна, пожалуйста <a href="https://www.x-cart.com/contact-us.htmlutm_source=XC5Install&amp;utm_medium=reqsFailure&amp;utm_campaign=XC5Install">свяжитесь с нами</a>',
+  'loopback_request.error_message_1' => 'Страница Мои Приложения (service.php) не доступна, пожалуйста <a href="https://www.x-cart.com/contact-us.htmlutm_source=XC5Install&amp;utm_medium=reqsFailure&amp;utm_campaign=XC5Install">свяжитесь с нами</a>',
   'DocBlocks support' => 'Поддержка DocBlocks',
   'doc_blocks_support.error_message_1' => 'PHP на вашем сервере не поддерживает DocBlock. Эта система необходима для работы X‑Cart 5.',
   'doc_blocks_support.error_message_2' => 'PHP на вашем сервере не поддерживает DocBlock. Эта система необходима для работы X‑Cart 5. Блокировка DocBlock может быть вызвана работой расширения eAccelerator. Отключите это расширение и попробуйте снова.',
@@ -263,6 +265,7 @@ $translation = array (
   'Default time zone' => 'Часовой пояс по умолчанию',
   'By default, dates in this site will be displayed in the chosen time zone.' => 'По умолчанию, календарная дата на этом сайте будет отображаться для выбранного часового пояса.',
   'The prefix of the shop tables in database' => 'Префикс для таблиц в базе данных',
+  'Default charset' => 'Кодировка по умолчанию',
   'Administrator zone (backoffice)' => 'Панель администрирования',
   'Customer zone (front-end)' => 'Витрина (главная страница)',
   'Setting up directories' => 'Настройка директорий',
@@ -279,15 +282,14 @@ $translation = array (
   'Strong' => 'Сложный',
   'Uploading dump.sql into database...' => 'Загрузка SQL-дампа в базу данных...',
   'Redirecting to the next step...' => 'Переход на следующий шаг...',
-  'Create an online store for free' => 'Создайте онлайн-магазин бесплатно',
-  'Consider hosting your X-Cart with us' => 'Попробуйте хостинг X-Cart у нас',
-  'VPS hosting for X-Cart. No installation hassle. Fully customizable.' => 'VPS-хостинг для X-Cart.<br />Никаких сложностей с установкой.<br />Полностью настраиваемый.',
+  'Get first 30 days for FREE' => 'Получи первые 30 дней бесплатно',
+  'Create Online Store with X‑Cart!' => 'Создайте интернет-магазин с X-Cart!',
+  'No limitations or transaction fees, Open source code for easy customization, Great 24/7 support' => 'Без ограничений или комиссий за транзакции, открытый исходный код для легкой настройки, поддержка 24/7',
   'Having trouble installing X-Cart? Check out our installation guide' => 'Проблемы с установкой X-Cart?<br />Найдите решение в <a href="https://kb.x-cart.ru/general_setup/installation_guide.html" target="_blank">руководстве</a>',
   'X-Cart can track and store user actions to improve the UI/UX and merchant experience. You can stop user action tracking at any time by removing the Concierge module.' => 'X-Cart может отслеживать и хранить историю действий пользователя для улучшения механизма взаимодействия с пользователем и предоставления продавцу расширенных возможностей взаимодействия с сайтом магазина. Вы можете отключить отслеживание действий пользователя в любой момент удалив модуль Concierge.',
   'config_file.error_message_1' => 'Файл конфигурации не существует, и его нельзя скопировать из стандартного файла конфигурации. Данный файл необходим для установки программы.<br /><br />Пожалуйста, выполните следующие действия: <br /><br />1. Откройте директорию :configPath<br />2. Скопируйте <i>:defaultConfigFileName</i> to <i>:configFileName</i><br />3. Установите права на запись <i>:configFileName</i><br /><br />Попробуйте снова.',
   'php_disabled_functions.error_message_1' => 'Следующие функции отключены:<br/>:missedFunctions<br/>Данные функции могут использоваться программным обеспечением в некоторых случаях, и их рекомендуется включить.',
   'mysql_version.error_message_2' => 'Сервер MySQL не поддерживает систему InnoDB. InnoDB необходима для корректной работы X-Cart.',
-  'mysql_cache.error_message_1' => 'Не включен кэш MySQL. Инструкция по включению доступна по ссылке <a href="https://dev.mysql.com/doc/refman/5.7/en/query-cache-configuration.html" target="_blank">https://dev.mysql.com/doc/refman/5.7/en/query-cache-configuration.html</a>.',
   'php_gdlib.error_message_2' => 'У расширения GDlib отсутствует плагин JPEG.',
   'php_phar.error_message_1' => 'Для получения обновлений и установки модулей требуется расширение Phar версии 2.0.1 или выше; в противном случае корректность работы данных функций не гарантируется.',
   'frame_options.error_message_1' => 'Ваш сервер отдает заголовок X-Frame-Options с значением DENY. Для успешной установки X-Cart необходимо настроить эту опцию так, что ее значение было SAMEORIGIN или ALLOW-FROM хост_сервера. После установки X-Cart можно изменить значение на DENY, если это требуется.',
