@@ -390,7 +390,7 @@ class Settings extends \XLite\Controller\Admin\AAdmin
                 break;
 
             case 'license_keys':
-                $return = \XLite\Core\Database::getRepo('XLite\Model\ModuleKey')->findAll();
+                $return = [];
                 break;
 
             default:
@@ -562,11 +562,14 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         $explanation = '';
         switch ($code) {
             case 500:
-                $explanation .= ': Internal server error';
+                $explanation .= 'Internal server error';
+                break;
+            case 404:
+                $explanation .= 'Page not found';
                 break;
         }
 
-        return static::t('Error code explanation:'). $code . ' '. $explanation;
+        return static::t('Error code explanation:') . ' ' . $code . ' '. $explanation;
     }
 
     /**
@@ -605,27 +608,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         $this->setSuppressOutput(true);
     }
 
-    /**
-     * Send specific headers and print AJAX data as JSON string
-     *
-     * @param array $data
-     *
-     * @return void
-     */
-    protected function printAJAX($data)
-    {
-        // Move top messages into headers since we print data and die()
-        $this->translateTopMessagesToHTTPHeaders();
-
-        $content = json_encode($data);
-
-        header('Content-Type: application/json; charset=UTF-8');
-        header('Content-Length: ' . strlen($content));
-        header('ETag: ' . md5($content));
-
-        print ($content);
-    }
-
     /**
      * Actions to enable the clean URL functionality
      *
@@ -677,58 +659,6 @@ class Settings extends \XLite\Controller\Admin\AAdmin
         return \XLite\Core\Database::getRepo('XLite\Model\State')->find($stateId);
     }
 
-    /**
-     * Flag to has email error
-     *
-     * @return string
-     */
-    public function hasTestEmailError()
-    {
-        return '' !== (string)\XLite\Core\Session::getInstance()->test_email_error;
-    }
-
-    /**
-     * Return error test email sending
-     *
-     * @return string
-     */
-    public function getTestEmailError()
-    {
-        $error = (string)\XLite\Core\Session::getInstance()->test_email_error;
-
-        \XLite\Core\Session::getInstance()->test_email_error = '';
-
-        return $error;
-    }
-
-    // }}}
-
-    // {{{ Service actions
-
-    /**
-     * Action to send test email notification
-     *
-     * @return void
-     */
-    protected function doActionTestEmail()
-    {
-        $request = \XLite\Core\Request::getInstance();
-
-        $error = \XLite\Core\Mailer::sendTestEmail(
-            $request->test_from_email_address,
-            $request->test_to_email_address,
-            $request->test_email_body
-        );
-
-        if ($error) {
-            \XLite\Core\Session::getInstance()->test_email_error = $error;
-            \XLite\Core\TopMessage::getInstance()->addError('Error of test e-mail sending: ' . $error);
-
-        } else {
-            \XLite\Core\TopMessage::getInstance()->add('Test e-mail have been successfully sent');
-        }
-    }
-
     // }}}
 
     // {{{ Requirements
