@@ -345,7 +345,24 @@ class Checkout extends \XLite\Controller\Customer\Cart
      */
     protected function markCartCalculate()
     {
-        return true;
+        $request = \XLite\Core\Request::getInstance();
+        return !($request->isAJAX() && $request->isGet() && isset($request->widget));
+    }
+
+    /**
+     * Assign additional data to cart during doPayment process
+     *
+     * @param $cart
+     */
+    protected function assignAdditionalDataToCart(\XLite\Model\Order $cart)
+    {
+        if (isset(\XLite\Core\Request::getInstance()->notes)) {
+            $cart->setNotes(\XLite\Core\Request::getInstance()->notes);
+        }
+
+        if ($cart->hasCartStatus()) {
+            $cart->setDate(\XLite\Core\Converter::time());
+        }
     }
 
     /**
@@ -360,13 +377,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
         $this->setHardRedirect();
         $cart = $this->getCart();
 
-        if (isset(\XLite\Core\Request::getInstance()->notes)) {
-            $cart->setNotes(\XLite\Core\Request::getInstance()->notes);
-        }
-
-        if ($cart->hasCartStatus()) {
-            $cart->setDate(\XLite\Core\Converter::time());
-        }
+        $this->assignAdditionalDataToCart($cart);
 
         // Get first (and only) payment transaction
         $transaction = $cart->getFirstOpenPaymentTransaction();
@@ -489,7 +500,7 @@ class Checkout extends \XLite\Controller\Customer\Cart
         } elseif ($cart->getOpenTotal() > 0) {
             // Order still not payed
             $this->assignTransactionMessage();
-            $this->setReturnURL($this->buildURL('checkout'));
+            $this->setReturnURL($this->getOpenTotalReturnURL($cart));
 
         } else {
             // Order payed or pending
@@ -513,6 +524,16 @@ class Checkout extends \XLite\Controller\Customer\Cart
         }
     }
 
+    /**
+     * @param $cart
+     *
+     * @return string
+     */
+    protected function getOpenTotalReturnURL(\XLite\Model\Order $cart)
+    {
+        return $this->buildURL('checkout');
+    }
+
     /**
      * Add top message about transaction results
      *
@@ -862,6 +883,16 @@ class Checkout extends \XLite\Controller\Customer\Cart
 
         $this->updateProfile();
 
+        if (!isset($this->requestData['same_address'])
+            && isset(\XLite\Core\Session::getInstance()->same_address)
+        ) {
+            $this->requestData['same_address'] = \XLite\Core\Session::getInstance()->same_address;
+        }
+
+        if (!$this->getCart()->isShippable()) {
+            $this->requestData['same_address'] = false;
+        }
+
         $this->updateShippingAddress();
 
         $this->updateBillingAddress();
@@ -1251,9 +1282,11 @@ class Checkout extends \XLite\Controller\Customer\Cart
             ->find(\XLite\Core\Request::getInstance()->methodId);
 
         if (!$pm) {
-            \XLite\Core\TopMessage::addError(
-                'No payment method selected'
-            );
+            if ($this->isPaymentNeeded()) {
+                \XLite\Core\TopMessage::addError(
+                    'No payment method selected'
+                );
+            }
 
         } else {
             $cart = $this->getCart();
