@@ -801,6 +801,7 @@ abstract class AProcessor extends \XLite\Base implements \SeekableIterator, \Cou
                 $result[] = array(
                     'file' => $outputFile,
                     'delta' => $delta,
+                    'rowsCount' => $i,
                 );
 
                 $delta += $i;
@@ -1269,13 +1270,16 @@ abstract class AProcessor extends \XLite\Base implements \SeekableIterator, \Cou
             $orig = $value;
 
             if (!$this->isColumnTagsAllowed($column)) {
-                $value = strip_tags($value);
+                $value = \XLite\Core\Converter::filterCurlyBrackets(strip_tags($value));
                 $wrnType = 'CMN-TAGS';
 
             } elseif (!$this->isColumnTrusted($column)) {
                 $value = \XLite\Core\HTMLPurifier::purify($value);
                 $wrnType = 'CMN-XSS';
                 $ignoreWarning = $this->isIgnoreXSSWarnings($column);
+
+            } else {
+                $value = \XLite\Core\Converter::filterCurlyBrackets($value);
             }
 
             if ($orig != $value && !$ignoreWarning) {
@@ -1405,10 +1409,9 @@ abstract class AProcessor extends \XLite\Base implements \SeekableIterator, \Cou
             if ($result) {
                 try {
                     if (!$model->isManaged()) {
-                        $model->getRepository()->insert($model);
+                        $model->getRepository()->insert($model, false);
                     } else {
                         \XLite\Core\Database::getEM()->persist($model);
-                        \XLite\Core\Database::getEM()->flush();
                     }
                 } catch (\Exception $e) {
                     \XLite\Logger::getInstance()->registerException($e);
@@ -2028,6 +2031,18 @@ abstract class AProcessor extends \XLite\Base implements \SeekableIterator, \Cou
         return !(bool) preg_match('/\D/S', trim($value));
     }
 
+    /**
+     * Verify value as unsigned integer
+     *
+     * @param mixed @value Value
+     *
+     * @return boolean
+     */
+    protected function verifyValueAsInteger($value)
+    {
+        return !(bool) preg_match('/[^0-9-]/S', trim($value));
+    }
+
     /**
      * Verify value as unsigned integer
      *
