@@ -9,6 +9,7 @@
 namespace XLite\Model\Base;
 
 use XLite\Core\ImageOperator;
+use XLite\Core\Skin;
 
 /**
  * Image abstract store
@@ -181,6 +182,15 @@ abstract class Image extends \XLite\Model\Base\Storage
             $newExtension = $this->getExtensionByMIME();
             $pathinfo = pathinfo($path);
 
+            if (!$newExtension) {
+                $this->loadErrorMessage = [
+                    'The file extension is forbidden ({{file}})',
+                    ['file' => $this->getFileName()],
+                ];
+
+                return false;
+            }
+
             $extension = isset($pathinfo['extension']) ? $pathinfo['extension'] : '';
 
             // HARDCODE for BUG-2520
@@ -217,11 +227,11 @@ abstract class Image extends \XLite\Model\Base\Storage
         $result = parent::renewByPath($path);
 
         if ($result) {
-            $data = @getimagesize($path);
+            $data = $this->getSystemImageData($path);
+
+            if (is_array($data) && count($data) > 0) {
+                $this->updateDimensionsSizes($data);
 
-            if (is_array($data)) {
-                $this->setWidth($data[0]);
-                $this->setHeight($data[1]);
                 $this->setMime($data['mime']);
                 $hash = \Includes\Utils\FileManager::getHash($path, false, $this->includeFilenameInHash);
                 if ($hash) {
@@ -236,6 +246,43 @@ abstract class Image extends \XLite\Model\Base\Storage
         return $result;
     }
 
+    public function updateDimensionsSizes(array $data = null)
+    {
+        if (!$data) {
+            $data = $this->getSystemImageData(
+                $this->getPath()
+            );
+        }
+
+        if ($data) {
+            $this->setWidth($data[0]);
+            $this->setHeight($data[1]);
+        }
+    }
+
+    public function updateMimeType(array $data = null)
+    {
+        if (!$data) {
+            $data = $this->getSystemImageData(
+                $this->getPath()
+            );
+        }
+
+        if ($data) {
+            $this->setMime($data['mime']);
+        }
+    }
+
+    /**
+     * @param $path
+     *
+     * @return array
+     */
+    protected function getSystemImageData($path)
+    {
+        return @getimagesize($path) ?: [];
+    }
+
     /**
      * Load from local file
      *
@@ -288,7 +335,9 @@ abstract class Image extends \XLite\Model\Base\Storage
                 $url = $retinaURL = $this->getURL();
 
             } else {
-                $name = $this->getPath();
+                $name = $this->getStorageType()===static::STORAGE_ABSOLUTE
+                    ? basename($this->getPath())
+                    : $this->getPath();
 
                 $size = ($width ?: 'x') . '.' . ($height ?: 'x');
                 $path = $retinaPath = $this->getResizedPath($size, $name);
@@ -407,7 +456,9 @@ abstract class Image extends \XLite\Model\Base\Storage
 
         list($newWidth, $newHeight) = $this->getCropDimensions($width, $height);
 
-        $name = $this->getPath();
+        $name = $this->getStorageType()===static::STORAGE_ABSOLUTE
+            ? basename($this->getPath())
+            : $this->getPath();
         $size = ($width ?: 'x') . '.' . ($height ?: 'x');
         $path = $this->getResizedPath($size, $name);
         $url = $this->getResizedPublicURL($size, $name);
@@ -662,51 +713,4 @@ abstract class Image extends \XLite\Model\Base\Storage
     {
         return $this->needProcess;
     }
-
-    /**
-     * Return base64 image data
-     *
-     * @param int|null $width
-     * @param int|null $height
-     *
-     * @return string
-     */
-    public function getBlurredImageData($width = null, $height = null)
-    {
-        if (
-            ImageOperator::getEngineType() === ImageOperator::ENGINE_SIMPLE
-            || !\XLite\Core\Layout::getInstance()->isLazyLoadEnabled()
-            || !\XLite\Core\Layout::getInstance()->isSkinAllowsPreloadedImages()
-        ) {
-            return null;
-        }
-
-        list($_w, $_h, $url, $_retinaUrl) = $this->doResize(
-            $width ?: $this->getBlurredImageDimensions()['w'],
-            $height ?: $this->getBlurredImageDimensions()['h']
-        );
-
-        if (static::isValueLocalURL($url)) {
-            $path = static::getLocalPathFromURL($url);   
-        } else {
-            $path = $url;
-        }
-
-        $type = pathinfo($path, PATHINFO_EXTENSION);
-        $data = file_get_contents($path);
-        $base64 = 'data:image/' . $type . ';base64,' . base64_encode($data);
-
-        return $base64;
-    }
-
-    /**
-     * @return array
-     */
-    protected function getBlurredImageDimensions()
-    {
-        return [
-            'w' => 10,
-            'h' => 10,
-        ];
-    }
 }
