@@ -28,6 +28,11 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     const CATEGORY_URL_FORMAT_NON_CANONICAL_EXT = 'domain/parent/goalcategory.html';
     const CATEGORY_URL_FORMAT_CANONICAL_EXT = 'domain/goalcategory.html';
 
+    const PRODUCT_URL_FORMAT_NO_EXT = 'domain/goalproduct';
+    const PRODUCT_URL_FORMAT_EXT = 'domain/goalproduct.html';
+
+    const PRODUCT_URL_CANONICAL_WITH_CATEGORY = 'domain/main_category_clean_url/product_clean_url';
+
     /**
      * Limit of iterations to generate clean URL
      */
@@ -109,16 +114,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return '[.\w_\-]*';
     }
 
-    /**
-     * Returns product url regexp pattern
-     *
-     * @return string
-     */
-    protected function getPatternProduct()
-    {
-        return $this->getCommonPattern() . '(\.' . static::CLEAN_URL_DEFAULT_EXTENSION . ')?';
-    }
-
     // }}}
 
     // {{{ URL Separator
@@ -441,7 +436,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
                 }
             }
 
-            if (!$tmpEntity && static::isCategoryUrlHasExt()) {
+            if (!$tmpEntity) {
                 $tmpEntity = $this->findCategoryConflictWithOtherTypes($cleanURL);
             }
             
@@ -506,10 +501,11 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param string              $url    URL
      * @param \XLite\Model\AEntity $entity Entity
+     * @param boolean             $ignoreExtension Ignore default extension
      *
      * @return string
      */
-    protected function postProcessURL($url, $entity)
+    protected function postProcessURL($url, $entity, $ignoreExtension = false)
     {
         $entityType = static::getEntityType($entity);
 
@@ -518,7 +514,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             : null;
 
         return method_exists($this, $method)
-            ? $this->{$method}($url, $entity)
+            ? $this->{$method}($url, $entity, $ignoreExtension)
             : $url;
     }
 
@@ -527,12 +523,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param string               $url    URL
      * @param \XLite\Model\AEntity $entity Entity
+     * @param boolean             $ignoreExtension Ignore default extension
      *
      * @return string
      */
-    protected function postProcessURLProduct($url, $entity)
+    protected function postProcessURLProduct($url, $entity, $ignoreExtension = false)
     {
-        return $url . '.' . static::CLEAN_URL_DEFAULT_EXTENSION;
+        return $url . ($this->isProductUrlHasExt() && !$ignoreExtension ? '.' . static::CLEAN_URL_DEFAULT_EXTENSION : '');
     }
 
     /**
@@ -540,12 +537,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param string               $url    URL
      * @param \XLite\Model\AEntity $entity Entity
+     * @param boolean             $ignoreExtension Ignore default extension
      *
      * @return string
      */
-    protected function postProcessURLCategory($url, $entity)
+    protected function postProcessURLCategory($url, $entity, $ignoreExtension = false)
     {
-        return $url . ($this->isCategoryUrlHasExt() ? '.' . static::CLEAN_URL_DEFAULT_EXTENSION : '');
+        return $url . ($this->isCategoryUrlHasExt() && !$ignoreExtension ? '.' . static::CLEAN_URL_DEFAULT_EXTENSION : '');
     }
 
     // }}}
@@ -664,7 +662,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     protected function prepareParseURL($url, $last, $rest, $ext, $target, $params)
     {
         if ('product' === $target) {
-            if (!empty($last) && !$this->isUseCanonicalURL()) {
+            if (!empty($last)) {
                 $path = explode('/', $rest);
                 $path[] = $last;
 
@@ -697,9 +695,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $result = null;
 
-        if ($ext) {
-            $result = $this->findByURL('product', $url . $ext);
-        }
+        $result = $this->findByURL('product', $url . $ext);
 
         return $result;
     }
@@ -829,7 +825,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             $entity = $this->findCategoryByURL($categoryURL, $parent);
 
             if (empty($entity)) {
-                if (static::isCategoryUrlHasExt() && (!static::isCategoryUrlCanonical() || !$this->isUseCanonicalURL())) {
+                if (static::isCategoryUrlHasExt() && !static::isCategoryUrlCanonical()) {
                     $entity = $this->findCategoryByURL($categoryURL . '.' . static::CLEAN_URL_DEFAULT_EXTENSION, $parent);
                 }
 
@@ -879,12 +875,19 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $queryBuilder = $this->defineFindEntityByURL('category', $url);
 
-        $queryBuilder->linkInner('c.category')
-            ->andWhere('category.parent = :parent')
-            ->setParameter('parent', $parent
-                ? $parent->getCategoryId()
-                : null)
-            ->orderBy('c.id', 'DESC');
+        if ($parent) {
+            $queryBuilder->linkInner('c.category')
+                ->andWhere('category.lpos > :parentLpos')
+                ->andWhere('category.rpos < :parentRpos')
+                ->setParameter('parentLpos', $parent->getLpos())
+                ->setParameter('parentRpos', $parent->getRpos())
+                ->orderBy('c.id', 'DESC');
+        } else {
+            $queryBuilder->linkInner('c.category')
+                ->andWhere('category.parent = :parent')
+                ->setParameter('parent', null)
+                ->orderBy('c.id', 'DESC');
+        }
 
         return $queryBuilder;
     }
@@ -949,16 +952,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return $result;
     }
 
-    /**
-     * Returns 'use_canonical_urls_only' option value
-     *
-     * @return boolean
-     */
-    public function isUseCanonicalURL()
-    {
-        return (bool) \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'use_canonical_urls_only'));
-    }
-
     /**
      * Returns 'category_clean_urls_format' option value
      *
@@ -978,6 +971,16 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             : static::CATEGORY_URL_FORMAT_NON_CANONICAL_NO_EXT;
     }
 
+    /**
+     * Returns 'use_canonical_urls_only' option value
+     *
+     * @return boolean
+     */
+    public function isUseCanonicalProductURLWithCategory()
+    {
+        return static::PRODUCT_URL_CANONICAL_WITH_CATEGORY === \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'canonical_product_clean_urls_format'));
+    }
+
     /**
      * Is use canonical url for categories
      *
@@ -1004,6 +1007,33 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         ]);
     }
 
+    /**
+     * Returns 'product_clean_urls_format' option value
+     *
+     * @return string
+     */
+    public static function getProductCleanUrlFormat()
+    {
+        $format = \Includes\Utils\ConfigParser::getOptions(array('clean_urls', 'product_clean_urls_format'));
+
+        return in_array($format, [
+            static::PRODUCT_URL_FORMAT_EXT,
+            static::PRODUCT_URL_FORMAT_NO_EXT
+        ])
+            ? $format
+            : static::PRODUCT_URL_FORMAT_NO_EXT;
+    }
+
+    /**
+     * Is use extension for categories
+     *
+     * @return boolean
+     */
+    public static function isProductUrlHasExt()
+    {
+        return static::getProductCleanUrlFormat() === static::PRODUCT_URL_FORMAT_EXT;
+    }
+
     /**
      * Analyze current target and request params and get a canonical redirect URL or null if redirect is not needed
      *
@@ -1015,17 +1045,6 @@ class CleanURL extends \XLite\Model\Repo\ARepo
     {
         $result = null;
 
-        if ($this->isUseCanonicalURL()) {
-            // Option use_canonical_urls_only is enabled: try to get canonical URL to redirect...
-
-            $tmp = \XLite\Core\Request::getInstance();
-
-            if ($this->isRedirectToCanonicalRequired($target, $tmp->url, $tmp->last, $tmp->rest, $tmp->ext)) {
-                list($target, $params) = $this->parseURL($tmp->url, $tmp->last, $tmp->rest, $tmp->ext);
-                $result = \XLite\Core\Converter::buildFullURL($target, '', $params);
-            }
-        }
-
         return $result;
     }
 
@@ -1060,20 +1079,18 @@ class CleanURL extends \XLite\Model\Repo\ARepo
 
             if (!empty($params['category_id'])) {
                 if ($repo->hasProduct($params['category_id'], $params['product_id'])) {
-                    if (!$this->isUseCanonicalURL()) {
-                        $categoryUrlParts = $this->getCategoryURLPath($params['category_id']);
+                    $categoryUrlParts = $this->getCategoryURLPath($params['category_id']);
 
-                        if ($this->isCategoryUrlHasExt()) {
-                            foreach ($categoryUrlParts as $k => $v) {
-                                $categoryUrlParts[$k] = str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $v);
-                            }
+                    if ($this->isCategoryUrlHasExt()) {
+                        foreach ($categoryUrlParts as $k => $v) {
+                            $categoryUrlParts[$k] = str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $v);
                         }
+                    }
 
-                        if ($categoryUrlParts) {
-                            $urlParts = array_merge($urlParts, $categoryUrlParts);
+                    if ($categoryUrlParts) {
+                        $urlParts = array_merge($urlParts, $categoryUrlParts);
 
-                            unset($params['category_id']);
-                        }
+                        unset($params['category_id']);
                     }
 
                 } else {
@@ -1110,6 +1127,41 @@ class CleanURL extends \XLite\Model\Repo\ARepo
         return [$urlParts, $params];
     }
 
+    /**
+     * Build canonical product URL
+     *
+     * @param array  $params Params
+     *
+     * @return array
+     */
+    public function buildURLProductCanonical($params)
+    {
+        list($urlParts, $params) = $this->buildURLProduct($params);
+
+        if ($this->isUseCanonicalProductURLWithCategory()) {
+            if ($product = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($params['product_id'])) {
+                /** @var \XLite\Model\Product $product */
+                if ($categoryId = $product->getCategoryId()) {
+                    $categoryUrlParts = $this->getCategoryURLPath($categoryId);
+
+                    if ($categoryUrlParts && $this->isCategoryUrlHasExt()) {
+                        foreach ($categoryUrlParts as $k => $v) {
+                            $categoryUrlParts[$k] = str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $v);
+                        }
+                    }
+
+                    if ($categoryUrlParts) {
+                        $urlParts = array_merge($urlParts, $categoryUrlParts);
+                    }
+                }
+            }
+        }
+
+        $result = implode('/', array_reverse($urlParts));
+
+        return $result;
+    }
+
     /**
      * Build category URL
      *
@@ -1150,38 +1202,31 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      */
     protected function getCategoryURLPath($categoryId)
     {
-        $categoriesDTO = \XLite\Core\Database::getRepo('XLite\Model\Category')->getAllCategoriesAsDTO();
-        $tmpCategoryId = $categoryId;
-        $rootCategoryId = \XLite\Core\Database::getRepo('XLite\Model\Category')->getRootCategoryId();
+        $category = \XLite\Core\Database::getRepo('XLite\Model\Category')->getCategory($categoryId);
 
-        $result = [];
-        while ($tmpCategoryId !== $rootCategoryId) {
-            if (!isset($categoriesDTO[$tmpCategoryId])) {
-                $result[] = null;
-                break;
-            }
-            $category = $categoriesDTO[$tmpCategoryId];
+        if (static::isCategoryUrlCanonical()) {
+            return $category
+                ? [$category->getCleanURL()]
+                : null;
+        } else {
+            $result = [];
+            $hasExt = static::isCategoryUrlHasExt();
 
-            $result[] = $category['cleanURL'];
-            $tmpCategoryId = (int) $category['parent_id'];
-        }
-        $result = array_reverse($result);
-
-        if (!empty($result)) {
-            if (static::isCategoryUrlCanonical()) {
-                $result = [array_pop($result)];
-            } elseif (static::isCategoryUrlHasExt()) {
-                $url = array_pop($result);
-                foreach ($result as $k => $v) {
-                    $result[$k] = str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $v);
+            $categories = $category->getPath();
+            $lastIndex = count($categories) - 1;
+            for ($i = $lastIndex; $i >= 0; $i--) {
+                $cleanUrl = $categories[$i]->getCleanURL();
+                if ($cleanUrl) {
+                    $result[] = $hasExt && $i !== $lastIndex
+                        ? str_replace('.' . static::CLEAN_URL_DEFAULT_EXTENSION, '', $cleanUrl)
+                        : $cleanUrl;
+                } else {
+                    return null;
                 }
-                $result[] = $url;
             }
-        }
 
-        return in_array(null, $result)
-            ? null
-            : array_reverse($result);
+            return $result;
+        }
     }
 
     // }}}
@@ -1193,10 +1238,11 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param \XLite\Model\AEntity|string $entity Entity
      * @param array                       $params Params OPTIONAL
+     * @param boolean                     $ignoreExtension Ignore default extension OPTIONAL
      *
      * @return string
      */
-    public function buildFakeURL($entity, array $params = array())
+    public function buildFakeURL($entity, array $params = array(), $ignoreExtension = false)
     {
         $result = '';
 
@@ -1207,7 +1253,7 @@ class CleanURL extends \XLite\Model\Repo\ARepo
             : null;
 
         $data = method_exists($this, $method)
-            ? $this->{$method}($entity, $params)
+            ? $this->{$method}($entity, $params, $ignoreExtension)
             : array();
 
         if ($data) {
@@ -1236,12 +1282,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param \XLite\Model\AEntity|string $entity Entity
      * @param array                       $params Params
+     * @param boolean                     $ignoreExtension Ignore default extension
      *
      * @return string
      */
-    protected function buildFakeURLProduct($entity, $params)
+    protected function buildFakeURLProduct($entity, $params, $ignoreExtension = false)
     {
-        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity));
+        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension));
 
         /** @var \XLite\Model\Product $entity */
 //        if (is_object($entity) && $entity->getCategoryId()) {
@@ -1256,12 +1303,13 @@ class CleanURL extends \XLite\Model\Repo\ARepo
      *
      * @param \XLite\Model\AEntity|string $entity Entity
      * @param array                       $params Params
+     * @param boolean                     $ignoreExtension Ignore default extension
      *
      * @return string
      */
-    protected function buildFakeURLCategory($entity, $params)
+    protected function buildFakeURLCategory($entity, $params, $ignoreExtension = false)
     {
-        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity));
+        $urlParts = array($this->postProcessURL(static::PLACEHOLDER, $entity, $ignoreExtension));
 
         /** @var \XLite\Model\Category $entity */
         if (is_object($entity) && $entity->getParentId() && !static::isCategoryUrlCanonical()) {
