@@ -26,15 +26,6 @@ abstract class Page extends \XLite\Module\CDev\SimpleCMS\View\CustomerPage imple
 
         $list[] = $this->getPage()->getOpenGraphMetaTags();
 
-        if (\XLite\Core\Config::getInstance()->CDev->GoSocial->gplus_use
-            && \XLite\Core\Config::getInstance()->CDev->GoSocial->gplus_page_id
-        ) {
-            $list[] = sprintf(
-                '<link href="https://plus.google.com/%s" rel="publisher" />',
-                \XLite\Core\Config::getInstance()->CDev->GoSocial->gplus_page_id
-            );
-        }
-
         return $list;
     }
 
