@@ -8,6 +8,7 @@
 
 namespace XLite\Module\QSL\CloudSearch\View;
 
+use XLite;
 use XLite\Module\QSL\CloudSearch\Main;
 
 
@@ -16,22 +17,6 @@ use XLite\Module\QSL\CloudSearch\Main;
  */
 abstract class AView extends \XLite\View\AView implements \XLite\Base\IDecorator
 {
-    /**
-     * Get a list of CSS files required to display the widget properly
-     *
-     * @return array
-     */
-    public function getCSSFiles()
-    {
-        $list = parent::getCSSFiles();
-
-        if (!\XLite::isAdminZone()) {
-            $list[] = 'modules/QSL/CloudSearch/style.less';
-        }
-
-        return $list;
-    }
-
     /**
      * Get a list of JS files required to display the widget properly
      *
@@ -41,16 +26,17 @@ abstract class AView extends \XLite\View\AView implements \XLite\Base\IDecorator
     {
         $list = parent::getJSFiles();
 
-        if (!\XLite::isAdminZone()) {
-            $list[] = 'modules/QSL/CloudSearch/loader.js';
+        if (!XLite::isAdminZone()) {
             $list[] = 'modules/QSL/CloudSearch/init.js';
-            $list[] = 'modules/QSL/CloudSearch/lib/handlebars.min.js';
-            $list[] = 'modules/QSL/CloudSearch/lib/jquery.hoverIntent.min.js';
+            $list[] = 'modules/QSL/CloudSearch/loader.js';
         }
 
         return $list;
     }
 
+    /**
+     * @return bool
+     */
     protected function isCloudFiltersMobileLinkVisible()
     {
         return Main::isCloudFiltersEnabled()
