@@ -1184,7 +1184,7 @@ XML;
 
         foreach (array('length', 'width', 'height') as $v) {
             $dimensions[$v] = static::adjustFloatValue(
-                $parcel->{'getBox' . \XLite\Core\Converter::convertToCamelCase($v)}(), 1, 0.1, 999.9
+                $parcel->{'getBox' . \XLite\Core\Converter::convertToCamelCase($v) . 'InCm'}(), 1, 0.1, 999.9
             );
         }
 
@@ -1408,7 +1408,7 @@ XML;
         if (static::getStringLength($value) == $max) {
             //check if HTML entity(&[some_code];) is truncated - remove it
             if (preg_match('/(&[^;]++)(?!;)$/', $value)) {
-                $value = static::subString($value, 0, $max - ($max - strrpos($value, '&') - 1));
+                $value = static::subString($value, 0, strrpos($value, '&'));
             }
         }
 
