@@ -32,16 +32,6 @@ class CanadaPost extends \XLite\Model\Shipping\Processor\AProcessor
         return 'capost';
     }
 
-    /**
-     * Returns processor name
-     *
-     * @return string
-     */
-    public function getProcessorName()
-    {
-        return 'Canada Post';
-    }
-
     /**
      * Returns settings template
      *
@@ -266,9 +256,23 @@ class CanadaPost extends \XLite\Model\Shipping\Processor\AProcessor
             \XLite\Core\Config::getInstance()->Units->weight_unit
         );
 
-        $limits['length'] = $config->length;
-        $limits['width']  = $config->width;
-        $limits['height'] = $config->height;
+        $limits['length'] = \XLite\Core\Converter::convertDimensionUnits(
+            $config->length,
+            'cm',
+            \XLite\Core\Config::getInstance()->Units->dim_unit
+        );
+
+        $limits['width'] = \XLite\Core\Converter::convertDimensionUnits(
+            $config->width,
+            'cm',
+            \XLite\Core\Config::getInstance()->Units->dim_unit
+        );
+
+        $limits['height'] = \XLite\Core\Converter::convertDimensionUnits(
+            $config->height,
+            'cm',
+            \XLite\Core\Config::getInstance()->Units->dim_unit
+        );
 
         return $limits;
     }
@@ -492,9 +496,21 @@ OUT;
         $dimensions = '';
 
         if (!empty($data['box'])) {
-            $length = $data['box']['length'];
-            $width  = $data['box']['width'];
-            $height = $data['box']['height'];
+            $length = \XLite\Core\Converter::convertDimensionUnits(
+                $data['box']['length'],
+                \XLite\Core\Config::getInstance()->Units->dim_unit,
+                'cm'
+            );
+            $width  = \XLite\Core\Converter::convertDimensionUnits(
+                $data['box']['width'],
+                \XLite\Core\Config::getInstance()->Units->dim_unit,
+                'cm'
+            );
+            $height = \XLite\Core\Converter::convertDimensionUnits(
+                $data['box']['height'],
+                \XLite\Core\Config::getInstance()->Units->dim_unit,
+                'cm'
+            );
 
         } elseif ($config->length && $config->width && $config->height) {
             $length = $config->length;
