@@ -19,6 +19,30 @@ class Product extends \XLite\Controller\Admin\Product implements \XLite\Base\IDe
      * @return void
      */
     protected function doActionUpdateAttributes()
+    {
+        $this->resetProductFilterCache();
+
+        parent::doActionUpdateAttributes();
+    }
+
+    /**
+     * Update products
+     *
+     * @return void
+     */
+    protected function doActionUpdate()
+    {
+        $this->resetProductFilterCache();
+
+        parent::doActionUpdate();
+    }
+
+    /**
+     * Reset product filter cache
+     *
+     * @return void
+     */
+    protected function resetProductFilterCache()
     {
         $categoriesToRemoveCache = array();
         foreach ($this->getProduct()->getCategoryProducts()->toArray() as $cp) {
@@ -30,7 +54,5 @@ class Product extends \XLite\Controller\Admin\Product implements \XLite\Base\IDe
                 $categoriesToRemoveCache
             );
         }
-
-        parent::doActionUpdateAttributes();
     }
 }
