@@ -11,7 +11,7 @@ namespace XLite\Module\XC\ProductFilter\Controller\Admin;
 /**
  * Settings page controller
  */
-class Settings extends \XLite\Controller\Admin\Settings implements \XLite\Base\IDecorator
+class Settings extends \XLite\Controller\Admin\Module implements \XLite\Base\IDecorator
 {
     /**
      * Remove product filter cache
@@ -24,4 +24,4 @@ class Settings extends \XLite\Controller\Admin\Settings implements \XLite\Base\I
 
         \XLite\Core\TopMessage::addInfo('The product filter cache has been removed successfully.');
     }
-}
\ No newline at end of file
+}
