@@ -24,6 +24,13 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
      */
     protected $variants = [];
 
+    /**
+     * List of provided variantIds
+     *
+     * @var array
+     */
+    protected $variantIds = [];
+
     /**
      * Product variants attributes
      *
@@ -64,6 +71,10 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
                 static::COLUMN_IS_MULTIROW => true,
                 static::COLUMN_LENGTH      => 255,
             ],
+            static::VARIANT_PREFIX . 'defaultValue' => [
+                static::COLUMN_IS_MULTIROW => true,
+                static::COLUMN_LENGTH      => 255,
+            ],
         ];
 
         $columns += [
@@ -96,7 +107,7 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
     // {{{ Verification
     protected function verifyData(array $data)
     {
-        $this->prepareVariants($data);
+        $this->prepareVariants($data, true);
 
         unset($data[static::VARIANT_PREFIX . 'ID']);
 
@@ -119,6 +130,9 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
                 'VARIANT-ATTRIBUTE-FMT'   => 'Variant attribute "{{column}}" cannot be empty',
                 'VARIANT-PRODUCT-FMT'     => 'Variant id X is already assigned to another product variant',
                 'VARIANT-SKU-FMT'         => 'Variant sku must be unique',
+                'VARIANT-ID-MISMATCH'     => 'Couldn\'t identify a variant based on ID X being imported',
+                'VARIANT-ID-CHANGED'      => 'variant ID X was replaced by ID Y generated automatically',
+                'VARIANT-TYPE-FMT'        => 'Field type for the attribute "{{value}}" is TEXT AREA; this type cannot be used to configure multiple attribute values.',
             ];
     }
 
@@ -229,6 +243,7 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
         if (is_array($value)) {
             $processed = [];
             foreach ($value as $id => $sku) {
+                $this->rowStartIndex = $id;
                 if (!empty($sku)) {
                     if (array_search($sku, $processed) !== false) {
                         $this->addError('VARIANT-SKU-FMT', [
@@ -345,22 +360,188 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
     /**
      * @param $data
      */
-    protected function prepareVariants($data)
+    protected function prepareVariants($data, $isVerification = false)
     {
         $this->variants = $this->variantsAttributes = [];
 
-        $key = static::VARIANT_PREFIX . 'ID';
-        if (isset($data[$key]) && is_array($data[$key])) {
-            foreach ($data[$key] as $index => $vId) {
-                $entity = Database::getRepo('XLite\Module\XC\ProductVariants\Model\ProductVariant')
-                    ->findOneBy(['variant_id' => $vId]);
-                if ($entity) {
-                    $this->variants[$index] = $entity;
+        $variantIdKey = static::VARIANT_PREFIX . 'ID';
+        $this->variantIds = !empty($data[$variantIdKey]) ? $data[$variantIdKey] : [];
+        if ($product = $this->detectModel($data)) {
+            if (isset($data[$variantIdKey]) && is_array($data[$variantIdKey])) {
+                foreach ($data[$variantIdKey] as $index => $vId) {
+                    $entity = Database::getRepo('XLite\Module\XC\ProductVariants\Model\ProductVariant')
+                        ->findOneBy(['variant_id' => $vId, 'product' => $product]);
+                    if ($entity) {
+                        $this->variants[$index] = $entity;
+                    }
+                }
+            }
+
+            if (isset($data['attributes'])) {
+                $variantsAttributes = $this->getVariantsAttributes($product, $data['attributes']);
+
+                if ($variantsAttributes) {
+                    foreach ($variantsAttributes as $rowIndex => $values) {
+                        if (!isset($this->variants[$rowIndex])) {
+                            $values = $this->getAttributeValuesByData($product, $values);
+                            $variant = $product->getVariantByAttributeValues($values, true);
+
+                            if ($variant && !in_array($variant, $this->variants, true)) {
+                                $this->variants[$rowIndex] = $variant;
+
+                                if ($isVerification && !empty($data[$variantIdKey][$rowIndex])) {
+                                    $this->addWarning('VARIANT-ID-MISMATCH', ['variantId' => $data[$variantIdKey][$rowIndex]], $rowIndex);
+                                }
+                            }
+                        }
+                    }
                 }
             }
         }
     }
 
+    /**
+     * Get variants attributes by attributes column data
+     *
+     * @param $model
+     * @param $attributeValues
+     * @return array
+     */
+    protected function getVariantsAttributes($model, $attributeValues)
+    {
+        $variantsAttributes = [];
+        foreach ($attributeValues as $attr => $attributeValue) {
+            if (!$this->isVariantValues($attributeValue)) {
+                continue;
+            }
+
+            if ($attributeStringData = $this->parseAttributeString($attr)) {
+                $type = $attributeStringData['type'];
+                $name = $attributeStringData['name'];
+                $productClass = 'class' === $type
+                    ? $model->getProductClass()
+                    : null;
+                $product = 'product' === $type
+                    ? $model
+                    : null;
+                $groupName = $attributeStringData['attributeGroup'] && 'product' !== $type
+                    ? $this->getDefLangValue($attributeStringData['attributeGroup'])
+                    : null;
+
+                $values = [];
+                foreach ($attributeValue as $value) {
+                    $values = array_merge($values, $value);
+                }
+                $values = array_values(array_unique($values));
+                $notEmptyValues = array_filter($values, function ($element) {
+                    return $element !== "";
+                });
+
+                if (empty($notEmptyValues) || ('class' === $type && !$productClass)) {
+                    continue;
+                }
+
+                $attributeGroup = null;
+
+                if ($groupName) {
+                    $attributeGroupCnd = new \XLite\Core\CommonCell();
+                    $attributeGroupCnd->{\XLite\Model\Repo\AttributeGroup::SEARCH_PRODUCT_CLASS} = $productClass;
+                    $attributeGroupCnd->{\XLite\Model\Repo\AttributeGroup::SEARCH_NAME} = $groupName;
+                    $result = \XLite\Core\Database::getRepo('XLite\Model\AttributeGroup')->search($attributeGroupCnd);
+                    if ($result) {
+                        $attributeGroup = reset($result);
+                    }
+                }
+
+                $attributeCnd = new \XLite\Core\CommonCell();
+
+                if ($product && $product->getId()) {
+                    $attributeCnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT} = $product;
+
+                } else {
+                    $attributeCnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT} = null;
+                }
+
+                $attributeCnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT_CLASS}   = $productClass;
+                $attributeCnd->{\XLite\Model\Repo\Attribute::SEARCH_ATTRIBUTE_GROUP} = $attributeGroup;
+                $attributeCnd->{\XLite\Model\Repo\Attribute::SEARCH_NAME}            = $name;
+
+                $attribute = \XLite\Core\Database::getRepo('XLite\Model\Attribute')->search($attributeCnd);
+
+                if ($attribute) {
+                    $attribute = $attribute[0];
+
+                } else {
+                    $variantsAttributes = [];
+                    break;
+                }
+
+                if ($attribute::TYPE_TEXT == $attribute->getType() && sizeof($attributeValue) > 1) {
+                    $this->addError('VARIANT-TYPE-FMT', ['value' => $attr]);
+                }
+
+                foreach ($attributeValue as $k => $value) {
+                    if (is_array($value)) {
+                        $value = reset($value);
+                    }
+                    if ($valueStringData = $this->parseAttributeValueString($value)) {
+                        $variantsAttributes[$k][$attribute->getId()][] = $valueStringData['value'];
+
+                    } else {
+                        $variantsAttributes[$k][$attribute->getId()][] = $value;
+                    }
+                }
+            }
+        }
+
+        return $variantsAttributes;
+    }
+
+    /**
+     * Get attribute values list by attribute values data [attributeId => attributeValueString]
+     *
+     * @param $model
+     * @param $values
+     * @return mixed
+     */
+    protected function getAttributeValuesByData($model, $values)
+    {
+        foreach ($values as $id => $value) {
+            if (!isset($this->variantsAttributes[$id])) {
+                $this->variantsAttributes[$id] = Database::getRepo('XLite\Model\Attribute')
+                    ->find($id);
+            }
+            $attribute = $this->variantsAttributes[$id];
+
+            $repo = Database::getRepo($attribute->getAttributeValueClass($attribute->getType()));
+            if ($attribute::TYPE_CHECKBOX == $attribute->getType()) {
+                if (is_array($value)) {
+                    $value = reset($value);
+                }
+                $values[$id] = $repo->findOneBy(
+                    [
+                        'attribute' => $attribute,
+                        'product'   => $model,
+                        'value'     => $this->normalizeValueAsBoolean($value),
+                    ]
+                );
+            } elseif ($attribute::TYPE_TEXT !== $attribute->getType()) {
+                $attributeOption = Database::getRepo('XLite\Model\AttributeOption')
+                    ->findOneByNameAndAttribute($value, $attribute);
+                $values[$id] = $repo->findOneBy(
+                    [
+                        'attribute'        => $attribute,
+                        'product'          => $model,
+                        'attribute_option' => $attributeOption,
+                    ]
+                );
+            }
+
+        }
+
+        return $values;
+    }
+
     /**
      * Import 'attributes' value
      *
@@ -370,6 +551,8 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
      */
     protected function importAttributesColumn(\XLite\Model\Product $model, array $value, array $column)
     {
+        $this->variantsAttributes = [];
+
         foreach ($value as $k => $v) {
             if (!$this->isVariantValues($v)) {
                 $value[$k] = array_splice($v, 0, 1);
@@ -378,9 +561,9 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
 
         parent::importAttributesColumn($model, $value, $column);
 
-        if ($this->multAttributes) {
-            Database::getEM()->flush();
+        Database::getEM()->flush();
 
+        if ($this->multAttributes) {
             $variantsAttributes = [];
             foreach ($this->multAttributes as $id => $values) {
                 if ($this->isVariantValues($values)) {
@@ -402,42 +585,13 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
                 }
                 if (count($tmp) === count($variantsAttributes)) {
                     foreach ($variantsAttributes as $rowIndex => $values) {
-                        foreach ($values as $id => $value) {
-                            if (!isset($this->variantsAttributes[$id])) {
-                                $this->variantsAttributes[$id] = Database::getRepo('XLite\Model\Attribute')
-                                    ->find($id);
-                            }
-                            $attribute = $this->variantsAttributes[$id];
-
-                            $repo = Database::getRepo($attribute->getAttributeValueClass($attribute->getType()));
-                            if ($attribute::TYPE_CHECKBOX == $attribute->getType()) {
-                                $values[$id] = $repo->findOneBy(
-                                    [
-                                        'attribute' => $attribute,
-                                        'product'   => $model,
-                                        'value'     => $this->normalizeValueAsBoolean($value),
-                                    ]
-                                );
-
-                            } else {
-                                $attributeOption = Database::getRepo('XLite\Model\AttributeOption')
-                                    ->findOneByNameAndAttribute($value, $attribute);
-                                $values[$id] = $repo->findOneBy(
-                                    [
-                                        'attribute'        => $attribute,
-                                        'product'          => $model,
-                                        'attribute_option' => $attributeOption,
-                                    ]
-                                );
-                            }
-
-                        }
+                        $values = $this->getAttributeValuesByData($model, $values);
+                        $variant = $model->getVariantByAttributeValues($values, true);
 
                         if (isset($this->variants[$rowIndex])) {
                             $idVariant = $this->variants[$rowIndex];
                         }
 
-                        $variant = $model->getVariantByAttributeValues($values, true);
                         $oldVariantId = $variant
                             ? $variant->getVariantId()
                             : null;
@@ -465,6 +619,10 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
 
                             if (!$oldVariantId) {
                                 $variant->setVariantId($variantsRepo->assembleUniqueVariantId($variant));
+
+                                if (isset($this->variantIds[$rowIndex]) && $this->variantIds[$rowIndex] !== $variant->getVariantId()) {
+                                    $this->addWarning('VARIANT-ID-CHANGED', ['oldVariantId' => $this->variantIds[$rowIndex], 'newVariantId' => $variant->getVariantId()], $rowIndex);
+                                }
                             }
                         }
 
@@ -485,6 +643,8 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
             }
 
             $model->assignDefaultVariant();
+        } else {
+            $model->checkVariants();
         }
     }
 
@@ -553,6 +713,20 @@ abstract class Products extends \XLite\Logic\Import\Processor\Products implement
         }
     }
 
+    /**
+     * Import 'variantdefaultValue' value
+     *
+     * @param \XLite\Model\Product $model Product
+     * @param mixed $value Value
+     * @param array $column Column info
+     */
+    protected function importVariantdefaultValueColumn(\XLite\Model\Product $model, $value, array $column)
+    {
+        foreach ($this->variants as $rowIndex => $variant) {
+            $variant->setDefaultValue($this->normalizeValueAsUinteger(isset($value[$rowIndex]) ? 1 : 0));
+        }
+    }
+
     /**
      * Import 'variantWeight' value
      *
