@@ -115,7 +115,6 @@ class Info extends \XLite\View\FormModel\AFormModel
                 [
                     'type'              => 'Symfony\Component\Form\Extension\Core\Type\ChoiceType',
                     'choices'           => array_flip($taxClasses),
-                    'choices_as_values' => true,
                     'placeholder'       => static::t('Default'),
                 ]
             );
@@ -147,9 +146,19 @@ class Info extends \XLite\View\FormModel\AFormModel
             $images = $product->getImages();
         }
 
+        $cleanUrlExt = \XLite\Model\Repo\CleanURL::isProductUrlHasExt() ? '.html' : '';
+
+        if ($product
+            && $product->getCleanURL()
+            && \XLite\Model\Repo\CleanURL::isProductUrlHasExt()
+            && !preg_match('/.html$/', $product->getCleanURL())
+        ) {
+            $cleanUrlExt = '';
+        }
+
         $schema = [
             self::SECTION_DEFAULT  => [
-                'name'                 => [
+                'name'               => [
                     'label'       => static::t('Product name'),
                     'required'    => true,
                     'constraints' => [
@@ -165,7 +174,7 @@ class Info extends \XLite\View\FormModel\AFormModel
                     ],
                     'position'    => 100,
                 ],
-                'sku'                  => [
+                'sku'                => [
                     'label'       => static::t('SKU'),
                     'constraints' => [
                         'XLite\Core\Validator\Constraints\MaxLength' => [
@@ -176,7 +185,7 @@ class Info extends \XLite\View\FormModel\AFormModel
                     ],
                     'position'    => 200,
                 ],
-                'images'               => [
+                'images'             => [
                     'label'      => static::t('Images'),
                     'type'       => 'XLite\View\FormModel\Type\UploaderType',
                     'imageClass' => 'XLite\Model\Image\Product\Image',
@@ -184,46 +193,25 @@ class Info extends \XLite\View\FormModel\AFormModel
                     'multiple'   => true,
                     'position'   => 300,
                 ],
-                'category'             => [
-                    'label'       => static::t('Category'),
-                    'description' => static::t('Switch to Category tree'),
-                    'type'        => 'XLite\View\FormModel\Type\ProductCategoryType',
-                    'multiple'    => true,
-                    'show_when'   => [
-                        'default' => [
-                            'category_widget_type' => 'search',
-                        ],
-                    ],
-                    'position'    => 400,
+                'category'           => [
+                    'label'    => static::t('Category'),
+                    'type'     => 'XLite\View\FormModel\Type\ProductCategoryType',
+                    'multiple' => true,
+                    'position' => 400,
                 ],
-                'category_tree'        => [
-                    'label'       => static::t('Category'),
-                    'description' => static::t('Switch to Category search'),
-                    'type'        => 'XLite\View\FormModel\Type\ProductCategoryTreeType',
-                    'multiple'    => true,
-                    'show_when'   => [
-                        'default' => [
-                            'category_widget_type' => 'tree',
-                        ],
-                    ],
-                    'position'    => 450,
-                ],
-                'category_widget_type' => [
-                    'type' => 'Symfony\Component\Form\Extension\Core\Type\HiddenType',
-                ],
-                'description'          => [
+                'description'        => [
                     'label'    => static::t('Description'),
                     'type'     => 'XLite\View\FormModel\Type\TextareaAdvancedType',
                     'position' => 500,
                 ],
-                'full_description'     => [
+                'full_description'   => [
                     'label'    => static::t('Full description'),
                     'type'     => 'XLite\View\FormModel\Type\TextareaAdvancedType',
                     'position' => 600,
                 ],
-                'available_for_sale'   => [
+                'available_for_sale' => [
                     'label'    => static::t('Available for sale'),
-                    'help'     => static::t('If the product is not available for sale, the system returns 404 response.'),
+                    'help'     => static::t('If the product is not available for sale, the system will return 404 response.'),
                     'type'     => 'XLite\View\FormModel\Type\SwitcherType',
                     'position' => 700,
                 ],
@@ -234,9 +222,9 @@ class Info extends \XLite\View\FormModel\AFormModel
                     'promoId' => 'wholesale-prices-1',
                 ],
                 'arrival_date'       => [
-                    'label'    => static::t('Arrival date'),
-                    'type'     => 'XLite\View\FormModel\Type\DatepickerType',
-                    'position' => 350,
+                    'label'       => static::t('Arrival date'),
+                    'type'        => 'XLite\View\FormModel\Type\DatepickerType',
+                    'position'    => 350,
                     'constraints' => [
                         'XLite\Core\Validator\Constraints\Timestamp' => [
                             'message' => static::t('[field] year must be between 1970 and 2038', ['field' => static::t('Arrival date')])
@@ -244,31 +232,30 @@ class Info extends \XLite\View\FormModel\AFormModel
                     ],
                 ],
                 'memberships'        => [
-                    'label'             => static::t('Memberships'),
-                    'type'              => 'XLite\View\FormModel\Type\Select2Type',
-                    'multiple'          => true,
-                    'choices'           => array_flip($memberships),
-                    'choices_as_values' => true,
-                    'position'          => 100,
+                    'label'    => static::t('Memberships'),
+                    'type'     => 'XLite\View\FormModel\Type\Select2Type',
+                    'multiple' => true,
+                    'choices'  => array_flip($memberships),
+                    'position' => 100,
                 ],
                 'tax_class'          => $taxClassSchema,
                 'price'              => [
-                    'label'       => static::t('Price'),
-                    'type'        => 'XLite\View\FormModel\Type\SymbolType',
-                    'symbol'      => $currencySymbol,
-                    'pattern'     => [
+                    'label'             => static::t('Price'),
+                    'type'              => 'XLite\View\FormModel\Type\SymbolType',
+                    'symbol'            => $currencySymbol,
+                    'inputmask_pattern' => [
                         'alias'      => 'xcdecimal',
                         'prefix'     => '',
                         'rightAlign' => false,
                         'digits'     => $currency->getE(),
                     ],
-                    'constraints' => [
+                    'constraints'       => [
                         'Symfony\Component\Validator\Constraints\GreaterThanOrEqual' => [
                             'value'   => 0,
                             'message' => static::t('Minimum value is X', ['value' => 0]),
                         ],
                     ],
-                    'position'    => 300,
+                    'position'          => 300,
                 ],
                 'inventory_tracking' => [
                     'label'       => static::t('Inventory tracking for this product is'),
@@ -280,20 +267,20 @@ class Info extends \XLite\View\FormModel\AFormModel
                             'position' => 100,
                         ],
                         'quantity'           => [
-                            'label'     => static::t('Quantity in stock'),
-                            'type'      => 'XLite\View\FormModel\Type\PatternType',
-                            'pattern'   => [
+                            'label'             => static::t('Quantity in stock'),
+                            'type'              => 'XLite\View\FormModel\Type\PatternType',
+                            'inputmask_pattern' => [
                                 'alias'      => 'integer',
                                 'rightAlign' => false,
                             ],
-                            'show_when' => [
+                            'show_when'         => [
                                 'prices_and_inventory' => [
                                     'inventory_tracking' => [
                                         'inventory_tracking' => '1',
                                     ],
                                 ],
                             ],
-                            'position'  => 200,
+                            'position'          => 200,
                         ],
                     ],
                     'position'    => 400,
@@ -301,16 +288,16 @@ class Info extends \XLite\View\FormModel\AFormModel
             ],
             'shipping'             => [
                 'weight'            => [
-                    'label'    => static::t('Weight'),
-                    'type'     => 'XLite\View\FormModel\Type\SymbolType',
-                    'symbol'   => Config::getInstance()->Units->weight_symbol,
-                    'pattern'  => [
+                    'label'             => static::t('Weight'),
+                    'type'              => 'XLite\View\FormModel\Type\SymbolType',
+                    'symbol'            => Config::getInstance()->Units->weight_symbol,
+                    'inputmask_pattern' => [
                         'alias'          => 'xcdecimal',
                         'digitsOptional' => false,
                         'rightAlign'     => false,
                         'digits'         => 4,
                     ],
-                    'position' => 100,
+                    'position'          => 100,
                 ],
                 'requires_shipping' => [
                     'label'    => static::t('Requires shipping'),
@@ -342,13 +329,18 @@ class Info extends \XLite\View\FormModel\AFormModel
                                     'position'  => 200,
                                 ],
                                 'items_in_box' => [
-                                    'label'            => static::t('Maximum items in box'),
-                                    'show_when' => [
+                                    'label'             => static::t('Maximum items in box'),
+                                    'type'              => 'XLite\View\FormModel\Type\PatternType',
+                                    'inputmask_pattern' => [
+                                        'alias'      => 'integer',
+                                        'rightAlign' => false,
+                                    ],
+                                    'show_when'         => [
                                         '..' => [
                                             'separate_box' => 1,
                                         ],
                                     ],
-                                    'position'  => 300,
+                                    'position'          => 300,
                                 ],
                             ],
                             'show_when'        => [
@@ -363,15 +355,14 @@ class Info extends \XLite\View\FormModel\AFormModel
             ],
             'marketing'            => [
                 'meta_description_type' => [
-                    'label'             => static::t('Meta description'),
-                    'type'              => 'Symfony\Component\Form\Extension\Core\Type\ChoiceType',
-                    'choices'           => array_flip([
+                    'label'       => static::t('Meta description'),
+                    'type'        => 'Symfony\Component\Form\Extension\Core\Type\ChoiceType',
+                    'choices'     => array_flip([
                         'A' => (string)static::t('Autogenerated'),
                         'C' => (string)static::t('Custom'),
                     ]),
-                    'choices_as_values' => true,
-                    'placeholder'       => false,
-                    'position'          => 100,
+                    'placeholder' => false,
+                    'position'    => 100,
                 ],
                 'meta_description'      => [
                     'label'              => ' ',
@@ -420,7 +411,7 @@ class Info extends \XLite\View\FormModel\AFormModel
                 'clean_url'             => [
                     'label'           => static::t('Clean URL'),
                     'type'            => 'XLite\View\FormModel\Type\CleanURLType',
-                    'extension'       => '.html',
+                    'extension'       => $cleanUrlExt,
                     'objectClassName' => 'XLite\Model\Product',
                     'objectId'        => $this->getDataObject()->default->identity,
                     'objectIdName'    => 'product_id',
@@ -434,6 +425,10 @@ class Info extends \XLite\View\FormModel\AFormModel
             $schema[self::SECTION_DEFAULT]['sku']['constraints']['Symfony\Component\Validator\Constraints\NotBlank'] = [
                 'message' => static::t('This field is required'),
             ];
+            $schema[self::SECTION_DEFAULT]['available_for_sale']['help'] = static::t(
+                'If the product is not available for sale, the system will return 404.',
+                ['productLink' => $product->getFrontURL(false, true)]
+            );
         }
 
         return $schema;
