@@ -313,7 +313,7 @@ class AdminMain extends \XLite\View\Model\AModel
                     }
                 }
 
-                if (!$value || !count($value)) {
+                if (!$value) {
                     $rootRole = \XLite\Core\Database::getRepo('XLite\Model\Role')->findOneRoot();
 
                     if ($rootRole) {
@@ -521,17 +521,6 @@ class AdminMain extends \XLite\View\Model\AModel
             $this->accessSchema['roles'][static::SCHEMA_REQUIRED] = false;
         }
 
-        $persistentModel = $this->getModelObject() && $this->getModelObject()->isPersistent();
-        if (!$persistentModel) {
-            $this->accessSchema['roles'][self::SCHEMA_COMMENT] = static::t(
-                'Attention! You are creating an account with full access. Roles warning',
-                [
-                    'roles_link' => $this->buildURL('roles'),
-                    'kb_link'    => static::t('https://kb.x-cart.com/users/user_roles.html'),
-                ]
-            );
-        }
-
         return $this->getFieldsBySchema($this->accessSchema);
     }
 
