@@ -36,7 +36,7 @@ class AddonKey extends \XLite\View\ModulesManager\AModulesManager
     public function getCSSFiles()
     {
         $list   = parent::getCSSFiles();
-        $list[] = $this->getDir() . '/style.css';
+        $list[] = $this->getDir() . '/style.less';
 
         return $list;
     }
