@@ -33,6 +33,27 @@ class Stock extends \XLite\View\Product\Details\Customer\Widget
         return 'product/details/stock/body.twig';
     }
 
+    /**
+     * Return available amount
+     *
+     * @return integer
+     */
+    protected function getItemsInCart()
+    {
+        return $this->getProduct()->getItemsInCart();
+    }
+
+    /**
+     * Return available amount
+     *
+     * @return integer
+     */
+    protected function getItemsInCartMessage()
+    {
+        return $this->getProduct()->getItemsInCartMessage();
+    }
+
+
     /**
      * Return available amount
      *
