@@ -9,6 +9,8 @@
 define('LC_ERR_TAG_MSG',   '@MSG@');
 define('LC_ERR_TAG_ERROR', '@ERROR@');
 define('LC_ERR_TAG_CODE',  '@CODE@');
+define('LC_CURRENT_YEAR', '@CURRENT_YEAR@');
+define('LC_CURRENT_VERSION', '@VERSION@');
 
 define('LC_ERROR_PAGE_MESSAGE', 'ERROR: "' . LC_ERR_TAG_ERROR . '" (' . LC_ERR_TAG_CODE . ') - ' . LC_ERR_TAG_MSG . LC_EOL);
 
@@ -25,12 +27,25 @@ function showErrorPage($code, $message, $page = LC_ERROR_PAGE_MESSAGE, $prefix =
 {
     header('Content-Type: text/html; charset=utf-8', true, $http_code);
 
-    echo str_replace(
-        array(LC_ERR_TAG_MSG, LC_ERR_TAG_ERROR, LC_ERR_TAG_CODE),
-        array($message, str_replace($prefix, '', $code), defined($code) ? constant($code) : 'N/A'),
+    $page = str_replace(
+        [
+            LC_ERR_TAG_MSG,
+            LC_ERR_TAG_ERROR,
+            LC_ERR_TAG_CODE,
+            LC_CURRENT_YEAR,
+            LC_CURRENT_VERSION
+        ],
+        [
+            $message,
+            str_replace($prefix, '', $code),
+            defined($code) ? constant($code) : 'N/A',
+            date('Y'),
+            LC_VERSION
+        ],
         $page
     );
 
+    echo '<script>document.addEventListener("DOMContentLoaded", function(event) {document.body.innerHTML=' . json_encode($page) . ';});</script>';
     exit (intval($code) ? $code : 1);
 }
 
