@@ -17,7 +17,7 @@ define('form_model/sticky_panel/non_sticky', ['js/vue/vue', 'form_model/sticky_p
 
           buttons
             .removeClass('disabled')
-            .removeProp('disabled');
+            .removeAttr('disabled');
 
           if (newValue) {
             buttons.each(function() {
