@@ -431,111 +431,109 @@ function attachTooltip(elm, content, forcePlacement, ttl) {
 }
 
 /**
- * Overlay registry
+ * Wait overlay
  */
-var waitOverlayRegistry = {};
 
 function assignWaitOverlay(elem) {
-  pattern = elem.prop('class');
-  if (!_.isUndefined(elem.get(0).waitOverlay) && elem.get(0).waitOverlay) {
-    unassignWaitOverlay(elem);
-  }
-
-  var div = jQuery('<div class="wait-block-overlay"><div class="wait-block"><div></div></div></div>');
-
-  div.css({
-    width: elem.outerWidth() + 'px',
-    height: elem.outerHeight() + 'px'
-  });
-
-  // We do not show the overlay if the element has zero width or height (the element is not visible)
-  if (0 !== elem.outerWidth() && 0 !== elem.outerHeight()) {
-    elem.prepend(div)
-  }
-  var leftOffset = elem.offset().left - div.offset().left;
-  var topOffset = elem.offset().top - div.offset().top;
-  div.css('margin-left', leftOffset + 'px');
-  div.css('margin-top', topOffset + 'px');
-
-  waitOverlayRegistry[pattern] = div;
-  elem.get(0).waitOverlay = div;
-
-  elem.trigger('assignOverlay', {widget: elem});
-
-  return div;
+  return createOverlay(elem, 'wait');
 }
 
 function unassignWaitOverlay(elem, force) {
-  pattern = elem.prop('class');
-  var overlay = null;
-  if (waitOverlayRegistry[pattern]) {
-    overlay = waitOverlayRegistry[pattern];
-
-  } else if (force) {
-    overlay = jQuery('.wait-block-overlay').eq(0);
-  }
-
-  if (overlay) {
-    overlay.remove();
-    if (elem.get(0)) {
-      elem.trigger('unassignOverlay', {widget: elem});
-      elem.get(0).waitOverlay = null;
-    }
-  }
+  return removeOverlay(elem, force);
 }
 
 /**
  * Shade overlay
  */
-var shadeOverlayRegistry = {};
 
 function assignShadeOverlay(elem) {
-  pattern = elem.prop('class');
-  if (!_.isUndefined(elem.get(0).shadeOverlay) && elem.get(0).shadeOverlay) {
-    unassignShadeOverlay(elem);
-  }
-
-  var div = jQuery('<div class="shade-block-overlay"></div>');
-
-  div.css({
-    width: elem.outerWidth() + 'px',
-    height: elem.outerHeight() + 'px'
-  });
-
-  // We do not show the overlay if the element has zero width or height (the element is not visible)
-  if (0 !== elem.outerWidth() && 0 !== elem.outerHeight()) {
-    elem.before(div)
-  }
-
-  var leftOffset = elem.offset().left - div.offset().left;
-  var topOffset = elem.offset().top - div.offset().top;
-  div.css('margin-left', leftOffset + 'px');
-  div.css('margin-top', topOffset + 'px');
-  shadeOverlayRegistry[pattern] = div;
-  elem.get(0).shadeOverlay = div;
-
-  elem.trigger('assignOverlay', {widget: elem});
-
-  return div;
+  return createOverlay(elem, 'shade');
 }
 
 function unassignShadeOverlay(elem, force) {
-  pattern = elem.prop('class');
-  var overlay = null;
-  if (shadeOverlayRegistry[pattern]) {
-    overlay = shadeOverlayRegistry[pattern];
+  return removeOverlay(elem, force);
+}
 
-  } else if (force) {
-    overlay = jQuery('.shade-block-overlay').eq(0);
-  }
+var overlayRegistry = {};
+var overlayAttr = 'data-overlay-id';
 
-  if (overlay) {
-    overlay.remove();
-    if (elem.get(0)) {
-      elem.trigger('unassignOverlay', {widget: elem});
-      elem.get(0).waitOverlay = null;
+function getOverlaySelector (elem) {
+  return elem.attr(overlayAttr) || generateOverlayId();
+}
+
+function generateOverlayId() {
+  do {
+    var pattern = 'overlay-' + Math.round(Math.random() * 1000000);
+    var isUnique = $('[' + overlayAttr + '=' + pattern + ']').length === 0;
+  } while (!isUnique);
+
+  return pattern;
+}
+
+function createOverlay(elem, type) {
+  type = type || 'wait';
+  var pattern = getOverlaySelector(elem);
+
+  $.each(elem, function() {
+    var elem = $(this);
+
+    if (!_.isUndefined(this.overlay) && this.overlay) {
+      unassignWaitOverlay(elem);
     }
-  }
+
+    var overlayElement = null;
+    if (type === 'wait') {
+      overlayElement = jQuery('<div class="wait-block-overlay"><div class="wait-block"><div></div></div></div>');
+    } else {
+      overlayElement = jQuery('<div class="shade-block-overlay"></div>');
+    }
+
+    overlayElement.css({
+      width: elem.outerWidth() + 'px',
+      height: elem.outerHeight() + 'px'
+    });
+
+    // We do not show the overlay if the element has zero width or height (the element is not visible)
+    if (0 !== elem.outerWidth() && 0 !== elem.outerHeight()) {
+      elem.prepend(overlayElement)
+    }
+
+    var leftOffset = elem.offset().left - overlayElement.offset().left;
+    var topOffset = elem.offset().top - overlayElement.offset().top;
+    overlayElement.css('margin-left', leftOffset + 'px');
+    overlayElement.css('margin-top', topOffset + 'px');
+
+    overlayElement.attr('id', pattern);
+    elem.attr(overlayAttr, pattern);
+    overlayRegistry[pattern] = overlayElement;
+    this.overlay = overlayElement;
+
+    elem.trigger('assignOverlay', {widget: elem, type: type});
+  });
+
+  return $('#' + pattern);
+}
+
+function removeOverlay(elem, force) {
+  var pattern = getOverlaySelector(elem);
+
+  $.each(elem, function() {
+    var elem = $(this);
+
+    var overlay = null;
+    if (pattern && typeof overlayRegistry[pattern] !== "undefined") {
+      overlay = overlayRegistry[pattern];
+    } else if (force) {
+      overlay = $('.wait-block-overlay, .shade-block-overlay');
+    }
+
+    if (overlay) {
+      overlay.remove();
+      elem.attr(overlayAttr, null);
+      elem.trigger('unassignOverlay', {widget: elem});
+      this.overlay = null;
+    }
+  });
 }
 
 function isBootstrapUse() {
@@ -755,6 +753,71 @@ CacheEngine.prototype.clear = function () {
   this.cache = [];
 };
 
+function getPasswordDifficulty(password) {
+  var digits = new RegExp('\\d');
+
+  var lowerLetters, upperLetters, specials;
+  try {
+    lowerLetters = new RegExp('\\p{Ll}', 'u');
+    upperLetters = new RegExp('\\p{Lu}', 'u');
+    specials = new RegExp('[^\\d\\p{L}]', 'u');
+  } catch (e) {
+    console.log("Current browser doesn't support regular expressions with unicode");
+    lowerLetters = new RegExp('[a-z]');
+    upperLetters = new RegExp('[A-Z]');
+    specials = new RegExp('[^A-Za-z\\d]');
+  }
+
+  var rating = 0;
+  [digits, lowerLetters, upperLetters, specials].forEach(function(item) {
+    if (item.test(password)) {
+      rating++;
+    }
+  });
+
+  if (password.length >= 6) {
+    rating++;
+  }
+
+  if (rating < 3) {
+    return 'Weak password';
+  }
+
+  return (rating < 4) ? 'Good password' : 'Strong password';
+}
+
+function showPasswordDifficultyMessage(elem, difficulty) {
+  elem.html(core.t(difficulty));
+}
+
+function setPasswordDifficultyColor(elem, difficulty) {
+  if (difficulty == 'Weak password') {
+    elem.css("color", "#D4142C");
+  } else if (difficulty == 'Good password') {
+    elem.css("color", "#F5A623");
+  } else if (difficulty == 'Strong password') {
+    elem.css("color", "#7ED321");
+  }
+}
+
+function smartTrim(string, maxLength) {
+  if (string.length <= maxLength) {
+    return string;
+  }
+
+  if (maxLength == 1) {
+    return string.substring(0,1) + '...';
+  }
+
+  const midpoint = Math.ceil(string.length / 2);
+  const toremove = string.length - maxLength;
+  const lstrip = Math.ceil(toremove/2);
+  const rstrip = toremove - lstrip;
+
+  return string.substring(0, midpoint-lstrip) + '...'
+    + string.substring(midpoint+rstrip);
+};
+
 jQuery(document).ready(
   function () {
     var isIE11 = !!navigator.userAgent.match(/Trident.*rv[ :]*11\./);
@@ -840,6 +903,58 @@ jQuery(document).ready(
       }
     );
 
+    core.microhandlers.add(
+      'input-file',
+      'input.inputfile',
+      function (event) {
+        $(this).change(function () {
+          if (this.files) {
+            var filename = '';
+            if (this.files.length > 1) {
+              filename = this.files.length + " files selected";
+            } else {
+              filename = this.files[0].name;
+            }
+
+            const filenameElement = $(this).siblings('span.input-filename');
+            if (filename) {
+              filenameElement.html(smartTrim(filename, 20));
+            }
+          }
+        });
+      }
+    );
+
+
+    if (xliteConfig.zone === 'customer') {
+      core.microhandlers.add(
+        '.profile-form',
+        'input#password',
+        function (event) {
+          $(this)
+            .filter(":last")
+            .on('input', function () {
+              var difficulty = getPasswordDifficulty($(this).val());
+
+              var form = $(this).closest('form');
+              var formId = form.attr('id')
+              var passwordDifficultyElem = $(".password-difficulty[form-id=" + formId + "]");
+
+              if (passwordDifficultyElem.length == 0) {
+                form.find('.password-label').append(
+                  "<span class='password-difficulty' form-id='" + formId + "'></span>"
+                );
+                passwordDifficultyElem = $(".password-difficulty[form-id=" + formId + "]");
+              }
+
+
+              showPasswordDifficultyMessage(passwordDifficultyElem, difficulty);
+              setPasswordDifficultyColor(passwordDifficultyElem, difficulty);
+            });
+        }
+      );
+    }
+
     core.bind('popup.open', function () {
       jQuery('html').addClass('popup-opened');
     });
