@@ -159,7 +159,6 @@ function CommonForm(form)
     this.commonController.setDependencyState(state);
   };
 
-  // Process form changed
   form.change(changeHandler);
 
   var state = this.checkDependencyState();
@@ -843,6 +842,10 @@ CommonElement.prototype.bindElement = function(elm)
     .keyup(debounced)
     .bind('paste', debounced);
 
+  if (this.$element.parents('.instant-control-readiness').length > 0) {
+    this.$element.keyup(_.debounce(_.bind(this.handleKeyUpControlReadiness, this), 100))
+  }
+
   this.triggerVent('bind');
 };
 
@@ -1565,7 +1568,7 @@ CommonElement.prototype.postprocessBackgroundSubmit = function()
     if (isElement(this.element, 'select')) {
       this.$element.removeClass('readonly-mark');
     }
-    this.$element.removeProp('readonly');
+    this.$element.prop('readonly', false);
     this.element.isTemporaryReadonly = null;
   }
 };
@@ -1731,7 +1734,7 @@ CommonElement.prototype.disable = function()
 {
   this.$element
     .addClass('disabled')
-    .prop('disabled', 'disabled');
+    .prop('disabled', true);
 };
 
 // Enable element
@@ -1739,7 +1742,7 @@ CommonElement.prototype.enable = function()
 {
   this.$element
     .removeClass('disabled')
-    .removeProp('disabled');
+    .prop('disabled', false);
 };
 
 CommonElement.prototype.handleChange = function(event)
@@ -1767,6 +1770,15 @@ CommonElement.prototype.handleKeyUp = function(event)
   }
 };
 
+CommonElement.prototype.handleKeyUpControlReadiness = function(event)
+{
+  var controlReadiness = this.element.form && this.element.form.commonController.controlReadiness;
+
+  if (controlReadiness) {
+    this.element.form.commonController.processReadiness();
+  }
+};
+
 CommonElement.prototype.handleValidationEngineResult = function(event, field, errorFound, prompText)
 {
   if (errorFound) {
