@@ -9,7 +9,7 @@
   var cs = document.createElement('script');
   cs.type = 'text/javascript'; 
   cs.async = true;
-  cs.src = 'https://cdn-qualiteamsoftwar.netdna-ssl.com/cloud_search_xcart.js';
+  cs.src = 'https://cdn-qualiteamsoftwar.netdna-ssl.com/cloud_search_xcart_v2.js';
 
   var s = document.getElementsByTagName('script')[0];
   s.parentNode.insertBefore(cs, s);
