@@ -106,13 +106,33 @@ abstract class ProductAbstract extends \XLite\Controller\Admin\ACL\Catalog
         $list['info'] = static::t('Info');
 
         if (!$this->isNew()) {
-            $list['attributes'] = static::t('Attributes');
+            $list['attributes'] = [
+                'title' => static::t('Attributes'),
+                'subTabsWidget' => '\XLite\View\Tabs\Attributes',
+                'subTabsWidgetParams' => [
+                    'product' => $this->getProduct()
+                ],
+            ];
             $list['inventory']  = static::t('Inventory tracking');
         }
 
         return $list;
     }
 
+    /**
+     * Get spages sections
+     *
+     * @return array
+     */
+    public function getSPages()
+    {
+        $list['global'] = static::t('Global');
+        $list['hidden'] = static::t('Hidden');
+        $list['custom'] = static::t('Custom');
+
+        return $list;
+    }
+
     /**
      * Get pages templates
      *
