@@ -33,6 +33,17 @@ abstract class TaxClassesAbstract extends \XLite\Controller\Admin\ACL\Catalog
         return static::t('Taxes');
     }
 
+    /**
+     * Update tax rate
+     *
+     * @return void
+     */
+    protected function doActionUpdate()
+    {
+        $list = new \XLite\View\ItemsList\Model\TaxClass();
+        $list->processQuick();
+    }
+
     /**
      * Export action
      *
