@@ -3,4 +3,4 @@ namespace XLite\Controller\Customer;
 /**
  * \XLite\Controller\Customer\Cart
  */
-class Cart extends \XLite\Module\CDev\Paypal\Controller\Customer\Cart {}
\ No newline at end of file
+class Cart extends \XLite\Module\Amazon\PayWithAmazon\Controller\Customer\Cart {}
\ No newline at end of file
