@@ -8,6 +8,9 @@
 
 namespace XLite\Core;
 
+use Includes\Utils\FileManager;
+use XLite\Core\Lock\FileLock;
+
 /**
  * Layout manager
  */
@@ -50,6 +53,9 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     const SIDEBAR_STATE_FIRST_ONLY_CATEGORIES = 4;
     const SIDEBAR_STATE_SECOND_ONLY_CATEGORIES = 8;
 
+    const INITIALIZE_LESS = 'bootstrap/css/initialize.less';
+    const MERGE_ROOT = 'root';
+
     /**
      * Widgets resources collector
      *
@@ -85,6 +91,13 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     protected $path;
 
+    /**
+     * Current skin web path
+     *
+     * @var string
+     */
+    protected $webPath;
+
     /**
      * Current interface
      *
@@ -122,6 +135,13 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     protected $skinPaths = array();
 
+    /**
+     * Skin paths
+     *
+     * @var array
+     */
+    protected $existingSkinPaths = array();
+
     /**
      * Resources cache
      *
@@ -171,6 +191,16 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
             ?: $this->getResourceWebPath('images/logo.png', static::WEB_PATH_OUTPUT_URL, \XLite::CUSTOMER_INTERFACE);
     }
 
+    /**
+     * Get apple icon
+     *
+     * @return string
+     */
+    public function getFavicon()
+    {
+        return $this->getResourceWebPath('favicon.ico', static::WEB_PATH_OUTPUT_URL, \XLite::ADMIN_INTERFACE);
+    }
+
     /**
      * Get apple icon
      *
@@ -187,7 +217,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
             $url = $this->getResourceWebPath('images/icon192x192.png', static::WEB_PATH_OUTPUT_URL, \XLite::COMMON_INTERFACE);
         }
 
-        return \XLite::getInstance()->getShopURL($url);
+        return $url;
     }
 
     // {{{ Layout changers methods
@@ -209,7 +239,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return void
      *
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function removeClassFromLists($class)
     {
@@ -241,7 +271,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return void
      *
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function removeClassFromList($class, $listName, $zone = null)
     {
@@ -285,7 +315,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      * @return \XLite\Model\ViewList New entry of the viewList
      *
      * @see \XLite\Model\ViewList
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function addClassToList($class, $listName, $options = array())
     {
@@ -317,7 +347,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return void
      *
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function removeTemplateFromLists($tpl)
     {
@@ -349,7 +379,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return void
      *
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function removeTemplateFromList($tpl, $listName, $zone = null)
     {
@@ -393,7 +423,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      * @return \XLite\Model\ViewList
      *
      * @see \XLite\Model\ViewList
-     * @see \XLite\Module\AModule::runBuildCacheHandler()
+     * @see \XLite\Module\AModule::updateViewListEntries()
      */
     public function addTemplateToList($tpl, $listName, $options = array())
     {
@@ -422,7 +452,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     protected function removeFromList($data)
     {
         $repo = \XLite\Core\Database::getRepo('\XLite\Model\ViewList');
-        $repo->deleteInBatch($repo->findBy($data), false);
+        $repo->deleteInBatch($repo->findBy($data));
     }
 
     /**
@@ -469,6 +499,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     public function getLESSResources($interface)
     {
         $result = array(
+            'bootstrap/css/initialize.less',
+            'bootstrap/css/bootstrap.less',
             'css/style.less',
         );
 
@@ -533,17 +565,6 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
         return $this->innerInterface;
     }
 
-    /**
-     * Return inner widget interface (compatibility alias)
-     *
-     * @deprecated
-     * @return string
-     */
-    public function getMailInterface()
-    {
-        return $this->getInnerInterface();
-    }
-
     /**
      * Returns the layout path
      *
@@ -554,6 +575,16 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
         return $this->path;
     }
 
+    /**
+     * Returns the layout web path
+     *
+     * @return string
+     */
+    public function getWebPath()
+    {
+        return $this->webPath;
+    }
+
     /**
      * Return list of all skins
      *
@@ -583,6 +614,45 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
         return $skin . (($this->locale && $this->locale != 'en') ? '_' . $this->locale : '');
     }
 
+    /**
+     *
+     */
+    public function getCurrentLayoutPreset()
+    {
+        return $this->getLayoutType();
+    }
+
+    /**
+     * Switches the layout type for the given layout group
+     *
+     * @param string $group
+     * @param string $type
+     * @return bool
+     */
+    public function switchLayoutType($group, $type)
+    {
+        $group = $group ?: static::LAYOUT_GROUP_DEFAULT;
+
+        $availableLayoutTypes = $this->getAvailableLayoutTypes();
+        $groupAvailableTypes = isset($availableLayoutTypes[$group])
+            ? $availableLayoutTypes[$group]
+            : [];
+
+        if (in_array($type, $groupAvailableTypes, true)) {
+            $group_suffix = ($group === static::LAYOUT_GROUP_DEFAULT ? '' : '_' . $group);
+
+            \XLite\Core\Database::getRepo('XLite\Model\Config')->createOption([
+                'category' => 'Layout',
+                'name' => 'layout_type' . $group_suffix,
+                'value' => $type,
+            ]);
+
+            return true;
+        }
+
+        return false;
+    }
+
     /**
      * Returns layout types
      *
@@ -606,7 +676,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return array
      */
-    public function getLayoutGroups()
+    public function getLayoutGroupTargets()
     {
         return array(
             static::LAYOUT_GROUP_HOME => array(
@@ -622,14 +692,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function getAvailableLayoutTypes()
     {
-        $module = \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule();
-
-        return $module
-            ? $this->getModuleLayoutTypes($module)
-            : array(
-                static::LAYOUT_GROUP_DEFAULT => $this->getLayoutTypes(),
-                static::LAYOUT_GROUP_HOME => $this->getLayoutTypes(),
-            );
+        return Skin::getInstance()->getAvailableLayoutTypes();
     }
 
     /**
@@ -698,116 +761,63 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     }
 
     /**
+     * @deprecated 5.4.0 Skin-related methods moved to \XLite\Core\Skin
+     * @see \XLite\Core\Skin::getAvailableLayoutColors()
      * Returns available layout colors
      *
      * @return array
      */
     public function getAvailableLayoutColors()
     {
-        $module = \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule();
-
-        return $module
-            ? $module->callModuleMethod('getLayoutColors', array())
-            : array();
+        return Skin::getInstance()->getAvailableLayoutColors();
     }
 
     /**
+     * @deprecated 5.4.0 Skin-related methods moved to \XLite\Core\Skin
+     * @see \XLite\Core\Skin::getSkinColorId()
      * Returns current layout type
      *
      * @return string
      */
     public function getLayoutColor()
     {
-        $layoutColor = Config::getInstance()->Layout->color;
-        $availableColors = $this->getAvailableLayoutColors();
-
-        return isset($availableColors[$layoutColor])
-            ? $layoutColor
-            : '';
+        return Skin::getInstance()->getSkinColorId();
     }
 
     /**
+     * @deprecated 5.4.0 Skin-related methods moved to \XLite\Core\Skin
+     * @see \XLite\Core\Skin::getSkinDisplayName()
      * Returns current layout type
      *
      * @return string
      */
     public function getLayoutColorName()
     {
-        $layoutColor = Config::getInstance()->Layout->color;
-        $availableColors = $this->getAvailableLayoutColors();
-
-        return isset($availableColors[$layoutColor])
-            ? $availableColors[$layoutColor]
-            : '';
+        return Skin::getInstance()->getSkinDisplayName();
     }
 
     /**
-     * Returns skin preview image URL
-     *
-     * @param \XLite\Model\Module $module Skin module
-     * @param string              $color  Color
-     * @param string              $type   Layout type
-     *
-     * @return string
-     */
-    public function getLayoutPreview($module, $color, $type)
-    {
-        $result = null;
-        $path = $module && $module instanceof \XLite\Model\Module
-            ? 'modules/' . $module->getAuthor() . '/' . $module->getName() . '/'
-            : 'images/layout/';
-
-        $image = 'preview' . ($color ? ('_' . $color) : '') . ($type ? ('_' . $type) : '') . '.jpg';
-        $result = $this->getResourceWebPath($path . $image);
-
-        if (null === $result) {
-            $image = 'preview' . ($color ? ('_' . $color) : '') . '.jpg';
-            $result = $this->getResourceWebPath($path . $image);
-        }
-
-        if (null === $result) {
-            $image = 'preview' . ($type ? ('_' . $type) : '') . '.jpg';
-            $result = $this->getResourceWebPath($path . $image);
-        }
-
-        if (null === $result) {
-            $image = 'preview.jpg';
-            $result = $this->getResourceWebPath($path . $image);
-        }
-
-        return $result ?: $this->getResourceWebPath('images/layout/preview_placeholder.jpg');
-    }
-
-    /**
-     * Returns current layout preview image URL
+     * @deprecated 5.4.0 Skin-related methods moved to \XLite\Core\Skin
+     * @see \XLite\Core\Skin::getCurrentLayoutPreview()
+     * Returns current skin + color + layout preview image
      *
      * @return string
      */
     public function getCurrentLayoutPreview()
     {
-        return $this->getLayoutPreview(
-            \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule(),
-            $this->getLayoutColor(),
-            $this->getLayoutType()
-        );
+        return Skin::getInstance()->getCurrentLayoutPreview();
     }
 
     /**
-     * Returns current layout images settings (sizes)
+     * @deprecated 5.4.0 Skin-related methods moved to \XLite\Core\Skin
+     * @see \XLite\Core\Skin::getCurrentImagesSettings()
+     * Returns current skin image settings
      *
      * @return \XLite\Model\ImageSettings[]
      */
     public function getCurrentImagesSettings()
     {
-        $currentSkinModule = \XLite\Core\Database::getRepo('XLite\Model\Module')
-            ->getCurrentSkinModule();
-
-        $skinModuleName = $currentSkinModule && $currentSkinModule->getActualName() !== "XC\ColorSchemes"
-            ? $currentSkinModule->getActualName()
-            : 'default';
-
-        return \XLite\Core\Database::getRepo('XLite\Model\ImageSettings')
-            ->findByModuleName($skinModuleName);
+        return Skin::getInstance()->getCurrentImagesSettings();
     }
 
     /**
@@ -870,9 +880,9 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function isCloudZoomAllowed()
     {
-        $skin = \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule();
+        $skin = Skin::getInstance()->getCurrentSkinModule();
 
-        return $skin ? $skin->callModuleMethod('isUseCloudZoom') : true;
+        return $skin ? $skin->callClassMethod('isUseCloudZoom') : true;
     }
 
     /**
@@ -892,21 +902,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function isSkinAllowsLazyLoad()
     {
-        $skin = \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule();
-
-        return $skin ? $skin->callModuleMethod('isUseLazyLoad') : false;
-    }
-
-    /**
-     * Check if image lazy loading is supported by skin
-     *
-     * @return bool|mixed
-     */
-    public function isSkinAllowsPreloadedImages()
-    {
-        $skin = \XLite\Core\Database::getRepo('XLite\Model\Module')->getCurrentSkinModule();
-
-        return $skin ? $skin->callModuleMethod('isUsePreloadedImages') : false;
+        return \Xlite\Core\Skin::getInstance()->isUseLazyLoad();
     }
 
     // }}}
@@ -977,13 +973,18 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     /**
      * Returns the resource full path
      *
-     * @param string $shortPath Short path
+     * @param array|string $shortPath Short path
      * @param string $interface Interface code OPTIONAL
      *
-     * @return string
+     * @return array|string
      */
     public function getResourceFullPath($shortPath, $interface = null)
     {
+        if (is_array($shortPath)) {
+            return array_map(function ($shortPath) use ($interface) {
+                return $this->getResourceFullPath($shortPath, $interface);
+            }, $shortPath);
+        }
         $interface = $interface ?: $this->currentInterface;
 
         $key = $this->prepareResourceKey($shortPath, $interface);
@@ -1079,10 +1080,11 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     /**
      * Get skin paths (file system and web)
      *
-     * @param string  $interface          Interface code OPTIONAL
-     * @param boolean $reset              Local cache reset flag OPTIONAL
-     * @param boolean $baseSkins          Use base skins only flag OPTIONAL
+     * @param string $interface Interface code OPTIONAL
+     * @param boolean $reset Local cache reset flag OPTIONAL
+     * @param boolean $baseSkins Use base skins only flag OPTIONAL
      * @param boolean $allInnerInterfaces
+     * @param array $locales
      *
      * @return array
      *
@@ -1090,20 +1092,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function getSkinPaths($interface = null, $reset = false, $baseSkins = false, $allInnerInterfaces = false)
     {
-        $interface = $interface ?: $this->currentInterface;
-
-        if (\XLite::MAIL_INTERFACE === $interface || \XLite::PDF_INTERFACE === $interface) {
-            $innerInterface = $this->getInnerInterface();
-            $key = $interface . '-' . $innerInterface;
-            $innerInterfaces = $allInnerInterfaces
-                ? [\XLite::CUSTOMER_INTERFACE, \XLite::COMMON_INTERFACE, \XLite::ADMIN_INTERFACE]
-                : [$innerInterface, \XLite::COMMON_INTERFACE];
-
-        } else {
-            $innerInterface = null;
-            $key = $interface;
-            $innerInterfaces = [$innerInterface];
-        }
+        /** @var array $innerInterfaces */
+        list($key, $innerInterfaces) = $this->getInterfacesByKey($interface, $allInnerInterfaces);
 
         if ($reset || !isset($this->skinPaths[$key])) {
             $this->skinPaths[$key] = [];
@@ -1146,6 +1136,70 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
         return $this->skinPaths[$key];
     }
 
+
+    /**
+     * Get skin paths
+     *
+     * @param null $interface
+     * @return array
+     */
+    public function getExistingCoreSkinPaths($interface = null)
+    {
+        /** @var array $innerInterfaces */
+        list($key, $innerInterfaces) = $this->getInterfacesByKey($interface, true);
+
+        if (!isset($this->existingSkinPaths[$key])) {
+            $paths = [];
+            $interfaceBasenames = $this->getBaseSkinByInterface($interface);
+            foreach ($interfaceBasenames as $name) {
+                $interfacePaths = FileManager::findFoldersStartingWithName(LC_DIR_SKINS, $name);
+                $paths = $interfacePaths;
+
+                if ($innerInterfaces && $innerInterfaces[0] !== null) {
+                    foreach ($innerInterfaces as $inner) {
+                        foreach ($interfacePaths as $basePath) {
+                            /** @noinspection SlowArrayOperationsInLoopInspection */
+                            $paths = array_merge(
+                                $paths,
+                                FileManager::findFoldersStartingWithName($basePath, $inner)
+                            );
+                        }
+                    }
+                }
+            }
+
+            $this->existingSkinPaths[$key] = $paths;
+        }
+
+        return $this->existingSkinPaths[$key];
+    }
+
+    /**
+     * @param string $interface
+     * @param bool $allInnerInterfaces
+     *
+     * @return array
+     */
+    protected function getInterfacesByKey($interface = null, $allInnerInterfaces = false)
+    {
+        $interface = $interface ?: $this->currentInterface;
+
+        if (\XLite::MAIL_INTERFACE === $interface || \XLite::PDF_INTERFACE === $interface) {
+            $innerInterface = $this->getInnerInterface();
+            $key = $interface . '-' . $innerInterface;
+            $innerInterfaces = $allInnerInterfaces
+                ? [\XLite::CUSTOMER_INTERFACE, \XLite::COMMON_INTERFACE, \XLite::ADMIN_INTERFACE]
+                : [$innerInterface, \XLite::COMMON_INTERFACE];
+
+        } else {
+            $innerInterface = null;
+            $key = $interface;
+            $innerInterfaces = [$innerInterface];
+        }
+
+        return [$key, $innerInterfaces];
+    }
+
     /**
      * Returns resource module path
      *
@@ -1288,6 +1342,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function setAdminSkin()
     {
+        $this->prepareResources();
+
         $this->currentInterface = \XLite::ADMIN_INTERFACE;
         $this->setSkin(static::PATH_ADMIN);
     }
@@ -1299,6 +1355,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function setConsoleSkin()
     {
+        $this->prepareResources();
+
         $this->currentInterface = \XLite::CONSOLE_INTERFACE;
         $this->setSkin(static::PATH_CONSOLE);
     }
@@ -1312,6 +1370,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function setMailSkin($interface = \XLite::CUSTOMER_INTERFACE)
     {
+        $this->prepareResources();
+
         $this->currentInterface = \XLite::MAIL_INTERFACE;
 
         $this->innerInterface = $interface;
@@ -1328,6 +1388,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function setPdfSkin($interface = \XLite::CUSTOMER_INTERFACE)
     {
+        $this->prepareResources();
+
         $this->currentInterface = \XLite::PDF_INTERFACE;
 
         $this->innerInterface = $interface;
@@ -1342,6 +1404,8 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     public function setCustomerSkin()
     {
+        $this->prepareResources();
+
         $this->skin = null;
         $this->locale = null;
         $this->currentInterface = \XLite::CUSTOMER_INTERFACE;
@@ -1396,6 +1460,21 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
             . LC_DS . $this->skin
             . ($this->locale && $this->locale != 'en' ? '_' . $this->locale : '')
             . LC_DS;
+
+        $this->setWebPath();
+    }
+
+    /**
+     * Set current skin web path
+     *
+     * @return void
+     */
+    protected function setWebPath()
+    {
+        $this->webPath = self::PATH_SKIN
+            . '/' . $this->skin
+            . ($this->locale && $this->locale != 'en' ? '_' . $this->locale : '')
+            . '/';
     }
 
     /**
@@ -1552,10 +1631,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      */
     protected function getPreparedResources()
     {
-        if (!$this->prepareResourcesFlag) {
-            $this->resources = $this->prepareResources($this->resources);
-            $this->prepareResourcesFlag = true;
-        }
+        $this->prepareResources();
 
         return $this->resources;
     }
@@ -1567,39 +1643,41 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
      *
      * @return array
      */
-    protected function prepareResources(array $resources)
+    protected function prepareResources()
     {
-        ksort($resources, SORT_NUMERIC);
+        if (!$this->prepareResourcesFlag) {
+            ksort($this->resources, SORT_NUMERIC);
 
-        foreach ($resources as $index => $subresources) {
-            foreach ($subresources as $type => $files) {
-                foreach ($files as $name => $file) {
-                    $file = $this->prepareResource($file, $type);
-                    if ($file) {
-                        $files[$name] = $file;
+            foreach ($this->resources as $index => $subresources) {
+                foreach ($subresources as $type => $files) {
+                    foreach ($files as $name => $file) {
+                        $file = $this->prepareResource($file, $type);
+                        if ($file) {
+                            $files[$name] = $file;
+
+                        } else {
+                            unset($files[$name]);
+                        }
+                    }
+
+                    if ($files) {
+                        $subresources[$type] = $files;
 
                     } else {
-                        unset($files[$name]);
+                        unset($subresources[$type]);
                     }
                 }
 
-                if ($files) {
-                    $subresources[$type] = $files;
+                if ($subresources) {
+                    $this->resources[$index] = $subresources;
 
                 } else {
-                    unset($subresources[$type]);
+                    unset($this->resources[$index]);
                 }
             }
 
-            if ($subresources) {
-                $resources[$index] = $subresources;
-
-            } else {
-                unset($resources[$index]);
-            }
+            $this->prepareResourcesFlag = true;
         }
-
-        return $resources;
     }
 
     /**
@@ -1771,11 +1849,12 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
             if (isset($resource['less'])) {
                 if ($resource['media'] === 'force_all') {
                     $resources[$index]['media'] = 'all';
-                } elseif (!isset($resource['merge']) && 'common' !== $resource['interface']) {
-                    $resource['merge'] = 'bootstrap/css/initialize.less';
+                } elseif (!isset($resource['merge'])
+                    && 'common' !== $resource['interface']) {
+                    $resource['merge'] = static::INITIALIZE_LESS;
                 }
 
-                if (isset($resource['merge'])) {
+                if (isset($resource['merge']) && $resource['merge'] !== static::MERGE_ROOT) {
                     $lessResources[$resource['merge']][] = $resource;
                     unset($resources[$index]);
                 }
@@ -1793,10 +1872,21 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
                     $lessGroup = array_merge(array($resource), $lessResources[$resource['original']]);
                 }
 
+                if (Request::getInstance()->isAJAX()) {
+                    if (FileLock::getInstance()->isRunning('cssMaking_' . $index)) {
+                        continue;
+                    }
+                    FileLock::getInstance()->setRunning('cssMaking_' . $index);
+                }
+
                 $resources[$index] = \XLite\Core\LessParser::getInstance()->makeCSS($lessGroup);
 
                 // Media type is derived from the parent resource
                 $resources[$index]['media'] = $resource['media'];
+
+                if (Request::getInstance()->isAJAX()) {
+                    FileLock::getInstance()->release('cssMaking_' . $index);
+                }
             }
         }
 
@@ -1947,7 +2037,7 @@ abstract class LayoutAbstract extends \XLite\Base\Singleton
     public function getCurrentLayoutGroup()
     {
         $target = \XLite\Core\Request::getInstance()->target;
-        $groups = $this->getLayoutGroups();
+        $groups = $this->getLayoutGroupTargets();
 
         $current = static::LAYOUT_GROUP_DEFAULT;
 
