@@ -60,6 +60,25 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
      */
     protected $languageCode = '';
 
+    /**
+     * @var string
+     */
+    protected $identifier;
+
+    /**
+     * Current request identifier
+     *
+     * @return string
+     */
+    public function getUniqueIdentifier()
+    {
+        if (null === $this->identifier) {
+            $this->identifier = hash('md5', uniqid('', true));
+        }
+
+        return $this->identifier;
+    }
+
     /**
      * @return string
      */
@@ -80,15 +99,6 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
         return $this;
     }
 
-    /**
-     * Drag-n-drop-cart feature is turned off for the mobile devices
-     *
-     * @return boolean
-     */
-    public static function isDragDropCartFlag()
-    {
-        return !static::isMobileDevice();
-    }
 
     /**
      * Detect Mobile version
@@ -147,7 +157,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
 
         $this->nonFilteredData = array_replace_recursive($this->data, $this->prepare($data));
 
-        $this->data = $this->filterData($this->nonFilteredData);
+        $this->data = $this->normalizeRequestData($this->filterData($this->nonFilteredData));
     }
 
     /**
@@ -451,6 +461,14 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
      */
     protected function normalizeRequestData($request)
     {
+        if (is_array($request)) {
+            array_walk_recursive($request, static function (&$item) {
+                $item = \XLite\Core\Converter::filterCurlyBrackets($item);
+            });
+        } else {
+            $request = \XLite\Core\Converter::filterCurlyBrackets($request);
+        }
+
         return $request;
     }
 
@@ -546,7 +564,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
 
         if ($secure) {
             $domain = $this->getCookieDomain(true);
-            $result = @setcookie(
+            $result = $this->_setcookie(
                 $name,
                 $value,
                 $ttl,
@@ -557,7 +575,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
             );
         } else {
             $httpDomain = $this->getCookieDomain(false);
-            $result = @setcookie(
+            $result = $this->_setcookie(
                 $name,
                 $value,
                 $ttl,
@@ -570,7 +588,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
             $httpsDomain = $this->getCookieDomain(true);
 
             if ($httpDomain != $httpsDomain) {
-                $result = @setcookie(
+                $result = $this->_setcookie(
                     $name,
                     $value,
                     $ttl,
@@ -595,7 +613,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
 
         if ($secure) {
             $domain = $this->getCookieDomain(true);
-            @setcookie(
+            $this->_setcookie(
                 $name,
                 null,
                 -1,
@@ -606,7 +624,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
             );
         } else {
             $httpDomain = $this->getCookieDomain(false);
-            @setcookie(
+            $this->_setcookie(
                 $name,
                 null,
                 -1,
@@ -618,7 +636,7 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
 
             $httpsDomain = $this->getCookieDomain(true);
             if ($httpDomain != $httpsDomain) {
-                @setcookie(
+                $this->_setcookie(
                     $name,
                     null,
                     -1,
@@ -631,6 +649,39 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
         }
     }
 
+    /**
+     * Wrapper for setcookie PHP function
+     */
+    public function _setcookie($name, $value = '', $expires = 0, $path = '', $domain = '', $secure = false, $httponly = false, $samesite = null)
+    {
+        $samesite = $samesite ?: $this->getCookieSameSiteOptionValue();
+
+        if (PHP_VERSION_ID >= 70300) {
+            $options = [
+                'expires' => $expires,
+                'path'    => $path,
+                'domain'  => $domain,
+                'secure'  => $secure,
+                'httponly' => $httponly,
+            ];
+
+            if ($samesite) {
+                $options['samesite'] = $samesite;
+            }
+
+            @setcookie($name, $value, $options);
+
+        } else {
+
+            if ($samesite) {
+                // Use a bug in PHP prior to v7.3.0 to pass 'samesite' option into cookie
+                $path .= '; samesite=' . $this->getCookieSameSiteOptionValue() . ';';
+            }
+
+            @setcookie($name, $value, $expires, $path, $domain, $secure, $httponly);
+        }
+    }
+
     /**
      * Get host / domain for Set-Cookie
      *
@@ -659,6 +710,16 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
         return isset($url['path']) ? $url['path'] : '/';
     }
 
+    /**
+     * Get samesite option value
+     *
+     * @return string
+     */
+    protected function getCookieSameSiteOptionValue()
+    {
+        return \Includes\Utils\ConfigParser::getOptions(array('other', 'cookie_samesite'));
+    }
+
     /**
      * Get parsed URL for Set-Cookie
      *
@@ -714,35 +775,26 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
             'X-Cart Catalog Generator',
         ),
         'Google'        => array(
-            'Googlebot',
             'Mediapartners-Google',
-            'Googlebot-Mobile',
-            'Googlebot-Image',
-            'Adsbot-Google',
             'Google Page Speed Insights',
+            'Google-Adwords-Instant',
+        ),
+        'Yandex'         => array(
+            'YandexImages',
+            'YandexMetrika',
+            'YandexImageResizer',
+            'YandexVideoParser',
         ),
         'Yahoo'            => array(
             'Slurp',
             'YahooSeeker',
         ),
-        'Microsoft'        => array(
-            'MSNBot',
-            'MSNBot-Media',
-            'MSNBot-NewsBlogs',
-            'MSNBot-Products',
-            'MSNBot-Academic',
-            'bingbot',
-            'adidxbot',
-        ),
         'Ask'            => array(
             'Teoma',
         ),
         'Baidu'          => array(
             'baiduspider',
         ),
-        'dotnetdotcom.org' => array(
-            'dotbot',
-        ),
         'Qihoo' => array(
             'Qihoo',
         ),
@@ -758,14 +810,18 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
         'NHN Corporation' => array(
             'Yeti',
         ),
-        'NetEase Inc' => array(
-           'YodaoBot',
-        ),
-        'MJ12bot' => array(
-           'MJ12bot',
-        ),
-        'AhrefsBot' => array(
-           'AhrefsBot',
+        'other' => array(
+            'special_archiver',
+            'SEOkicks',
+            'idmarch',
+            'Qwantify',
+            'TagVisit',
+            'FastCrawler',
+            'Pandalytics',
+            'Veooz',
+            'Mappy',
+            'Nmap Scripting Engine',
+            'linkfluence.com',
         ),
     );
 
@@ -809,6 +865,10 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
     {
         $result = false;
 
+        if (false !== stristr($_SERVER['HTTP_USER_AGENT'], 'bot')) {
+            return true;
+        }
+
         foreach ($this->botSignatures as $name => $signatures) {
             foreach ($signatures as $signature) {
                 if (false !== stristr($_SERVER['HTTP_USER_AGENT'], $signature)) {
@@ -909,4 +969,36 @@ abstract class RequestAbstract extends \XLite\Base\Singleton
 
         return $ipAddress;
     }
+
+    /**
+     * Return true if current userAgent is IE
+     *
+     * @return boolean
+     */
+    public function isIE()
+    {
+        $result = false;
+
+        // Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; NP06; rv:11.0) like Gecko
+        $ua = htmlentities($_SERVER['HTTP_USER_AGENT'], ENT_QUOTES, 'UTF-8');
+        if (preg_match('~MSIE|Internet Explorer~i', $ua) || preg_match('~Trident/7\.0;(?:.*) rv:11\.0~i', $ua)) {
+            $result = true;
+        }
+
+        return $result;
+    }
+
+    /**
+     * Returns customer user agent
+     *
+     * @return string
+     */
+    public function getClientUserAgent()
+    {
+        if (isset($_SERVER['HTTP_USER_AGENT'])) {
+            return $_SERVER['HTTP_USER_AGENT'];
+        }
+
+        return 'UNKNOWN';
+    }
 }
