@@ -457,8 +457,6 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
 
             $this->__set('language', $code);
             $this->language = null;
-
-            \XLite\Core\Request::getInstance()->setLanguageCode($language);
         }
     }
 
@@ -558,8 +556,9 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
             if ('COOKIE' === $source) {
 
                 // DO NOT Change the current session if the $sid goes from COOKIE
-                $this->session->updateExpiry();
-                \XLite\Core\Database::getEM()->flush($this->session);
+                if ($this->session->updateExpiry()) {
+                    \XLite\Core\Database::getEM()->flush($this->session);
+                }
 
             } else {
 
@@ -669,7 +668,7 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
                 \XLite\Core\Request::getInstance()->setCookie(
                     $this->getName(),
                     $this->getID(),
-                    static::getTTL()
+                    \XLite\Model\Session::getMaxTTL()
                 );
 
                 $this->setLCRefererCookie();
@@ -773,8 +772,10 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
 
         $useCleanUrls = defined('LC_USE_CLEAN_URLS') && true == LC_USE_CLEAN_URLS;
 
-        if ($useCleanUrls && \XLite\Core\Router::getInstance()->isUseLanguageUrls() && \XLite\Core\Request::getInstance()->getLanguageCode()) {
-            $code = array_merge($code, ['customer' => \XLite\Core\Request::getInstance()->getLanguageCode()]);
+        $languageCodeFromRequest = \XLite\Core\Request::getInstance()->getLanguageCode();
+
+        if ($useCleanUrls && \XLite\Core\Router::getInstance()->isUseLanguageUrls() && $languageCodeFromRequest) {
+            $code = array_merge($code, ['customer' => $languageCodeFromRequest]);
         }
 
         if (!empty($code[$zone])) {
@@ -782,9 +783,9 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
 
             if (!isset($language) || !$language->getAdded() || !$language->getEnabled()) {
                 unset($code[$zone]);
-            } elseif ($useCleanUrls && \XLite\Core\Router::getInstance()->isUseLanguageUrls() && \XLite\Core\Request::getInstance()->getLanguageCode()) {
+            } elseif ($useCleanUrls && \XLite\Core\Router::getInstance()->isUseLanguageUrls() && $languageCodeFromRequest) {
                 $lang = $this->__get('language') ?: [];
-                $lang['customer'] = \XLite\Core\Request::getInstance()->getLanguageCode();
+                $lang['customer'] = $languageCodeFromRequest;
                 $this->__set('language', $lang);
             }
         }
@@ -876,6 +877,7 @@ abstract class SessionAbstract extends \XLite\Base\Singleton
         return !\XLite\Core\Request::getInstance()->isCLI()
             && \XLite\Core\Config::getInstance()->General
             && \XLite\Core\Config::getInstance()->General->internal_cron_enabled
+            && null !== $this->session
             && 0 === $this->session->getId() % 100;
     }
 
