@@ -253,7 +253,9 @@ abstract class ImporterAbstract extends \XLite\Base
         }
 
         // Preprocess import data
-        $this->preprocessImport();
+        $rowsCount = $this->preprocessImport();
+
+        $this->getOptions()->rowsCount = $rowsCount;
 
         // Save import options if they were changed
         $record = \XLite\Core\Database::getRepo('XLite\Model\TmpVar')->getEventState('import');
@@ -286,14 +288,16 @@ abstract class ImporterAbstract extends \XLite\Base
     /**
      * Preprocess import data.
      * Check size limit of CSV files and divide them on several small parts.
-     * Returns true if file was divided
+     * Returns total count or rows
      *
-     * @return boolean
+     * @return int
      */
     protected function preprocessImport()
     {
         $newFiles = array();
 
+        $totalRows = 0;
+
         foreach ($this->getProcessors() as $processor) {
             $files = $processor->getFiles(true);
             foreach ($files as $file) {
@@ -301,11 +305,18 @@ abstract class ImporterAbstract extends \XLite\Base
                 $fileName = $file->getBasename();
 
                 if (false === strpos($fileName, static::PART_IDENTIFIER) && $fileSize > static::MAX_FILE_SIZE) {
-                    $newFiles[$file->getRealPath()] = $processor->divideCSVFile($file);
+                    $dividedFiles = $processor->divideCSVFile($file);
+                    $newFiles[$file->getRealPath()] = $dividedFiles;
+
+                    $totalRows += array_reduce($dividedFiles, static function ($carry, $item) {
+                        return $carry + $item['rowsCount'];
+                    }, 0);
 
                 } elseif (0 < $fileSize) {
                     // Add empty line at the end to avoid problems in some environments (see BUG-2636)
                     $this->correctLastNewline($file);
+
+                    $totalRows += $processor->count();
                 }
             }
         }
@@ -327,7 +338,7 @@ abstract class ImporterAbstract extends \XLite\Base
             }
         }
 
-        return !empty($newFiles);
+        return $totalRows;
     }
 
     /**
@@ -652,6 +663,7 @@ abstract class ImporterAbstract extends \XLite\Base
             'XLite\Logic\Import\Processor\AttributeValues\AttributeValueCheckbox',
             'XLite\Logic\Import\Processor\AttributeValues\AttributeValueSelect',
             'XLite\Logic\Import\Processor\AttributeValues\AttributeValueText',
+            'XLite\Logic\Import\Processor\AttributeValues\AttributeValueHidden',
             'XLite\Logic\Import\Processor\Customers',
         );
     }
