@@ -7,4 +7,4 @@ namespace XLite\Module\CDev\Coupons\View;
  * @ListChild (list="checkout.review.selected", weight="15")
  * @ListChild (list="checkout_fastlane.sections.details", weight="200")
  */
-class CartCoupons extends \XLite\Module\XC\CrispWhiteSkin\View\CartCoupons {}
\ No newline at end of file
+class CartCoupons extends \XLite\Module\Amazon\PayWithAmazon\Module\CDev\Coupons\View\CartCoupons {}
\ No newline at end of file
