@@ -37,11 +37,11 @@ abstract class RemoveData extends \XLite\Module\CDev\SimpleCMS\View\ItemsList\Mo
      *
      * @return string
      */
-    protected function buildMetodName(\XLite\Model\AEntity $entity, $pattern)
+    protected function buildMethodName(\XLite\Model\AEntity $entity, $pattern)
     {
         return static::TYPE_COUPONS === $entity->getId()
             ? sprintf($pattern, 'Coupons')
-            : parent::buildMetodName($entity, $pattern);
+            : parent::buildMethodName($entity, $pattern);
     }
 
     /**
@@ -53,14 +53,4 @@ abstract class RemoveData extends \XLite\Module\CDev\SimpleCMS\View\ItemsList\Mo
     {
         return 0 < \XLite\Core\Database::getRepo('XLite\Module\CDev\Coupons\Model\Coupon')->count();
     }
-
-    /**
-     * Remove coupons
-     *
-     * @return integer
-     */
-    protected function removeCoupons()
-    {
-        return $this->removeCommon('XLite\Module\CDev\Coupons\Model\Coupon');
-    }
 }
