@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\Egoods\Core;
 /**
  * Order history main point of execution
  */
- class OrderHistory extends \XLite\Module\CDev\XPaymentsConnector\Core\OrderHistory implements \XLite\Base\IDecorator
+ class OrderHistory extends \XLite\Module\XC\NotFinishedOrders\Core\OrderHistory implements \XLite\Base\IDecorator
 {
     const TXT_DELIVERED_BY_DOWNLOAD  = 'Order fulfilment status changed from {{oldStatus}} to {{newStatus}} by file download';
 
