@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\Egoods\View;
 /**
  * Invoice 
  */
-abstract class Invoice extends \XLite\Module\CDev\XPaymentsConnector\View\Invoice implements \XLite\Base\IDecorator
+abstract class Invoice extends \XLite\Module\QSL\BraintreeVZ\View\Invoice implements \XLite\Base\IDecorator
 {
     /**
      * Register CSS files
