@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\MarketPrice\Logic\BulkEdit;
 /**
  * @Decorator\Depend ("XC\BulkEditing")
  */
- class Scenario extends \XLite\Module\CDev\PINCodes\Logic\BulkEdit\Scenario implements \XLite\Base\IDecorator
+ class Scenario extends \XLite\Module\CDev\Sale\Logic\BulkEdit\Scenario implements \XLite\Base\IDecorator
 {
     /**
      * @return array
