@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\PINCodes\View\Tabs;
 /**
  * Tabs related to user profile section
  */
-abstract class Account extends \XLite\Module\CDev\XPaymentsConnector\View\Tabs\Account implements \XLite\Base\IDecorator
+abstract class Account extends \XLite\Module\QSL\BraintreeVZ\View\Tabs\Account implements \XLite\Base\IDecorator
 {
     /**
      * Returns the list of targets where this widget is available
