@@ -13,7 +13,7 @@ use XLite\Module\CDev\Paypal;
 /**
  * Abstract customer
  */
-abstract class ACustomer extends \XLite\Module\CDev\XPaymentsConnector\Controller\Customer\ACustomer implements \XLite\Base\IDecorator
+abstract class ACustomer extends \XLite\Module\XC\CanadaPost\Controller\Customer\ACustomer implements \XLite\Base\IDecorator
 {
     /**
      * Defines the common data for JS
