@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\Paypal\Controller\Customer;
 /**
  * Web-based payment method return
  */
- class PaymentReturn extends \XLite\Module\CDev\XPaymentsConnector\Module\XC\FastLaneCheckout\Controller\Customer\PaymentReturn implements \XLite\Base\IDecorator
+ class PaymentReturn extends \XLite\Module\QSL\BraintreeVZ\Controller\Customer\PaymentReturn implements \XLite\Base\IDecorator
 {
     protected $reload = false;
 
