@@ -13,7 +13,7 @@ namespace XLite\Module\CDev\Paypal\Module\XC\FastLaneCheckout\View;
  *
  * @Decorator\Depend("XC\FastLaneCheckout")
  */
- class SectionsNavigation extends \XLite\Module\CDev\XPaymentsConnector\Module\XC\FastLaneCheckout\View\SectionsNavigation implements \XLite\Base\IDecorator
+ class SectionsNavigation extends \XLite\Module\XC\FastLaneCheckout\View\SectionsNavigationAbstract implements \XLite\Base\IDecorator
 {
     /**
      * Defines the additional data array
