@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\Paypal\View\Checkout;
 /**
  * Shipping methods list
  */
- class PaymentMethodsList extends \XLite\Module\CDev\XPaymentsConnector\View\Checkout\PaymentMethodsList implements \XLite\Base\IDecorator
+ class PaymentMethodsList extends \XLite\View\Checkout\PaymentMethodsListAbstract implements \XLite\Base\IDecorator
 {
     /**
      * Return list of available payment methods
