@@ -12,7 +12,7 @@ namespace XLite\Module\CDev\Paypal\View\Model\Profile;
  * \XLite\View\Model\Profile\AdminMain
  * @Decorator\Depend ("!CDev\SocialLogin")
  */
- class AdminMain extends \XLite\View\Model\Profile\AdminMainAbstract implements \XLite\Base\IDecorator
+ class AdminMain extends \XLite\Module\CDev\UserPermissions\View\Model\Profile\AdminMain implements \XLite\Base\IDecorator
 {
     /**
      * Return fields list by the corresponding schema
