@@ -39,7 +39,7 @@ namespace XLite\Module\CDev\Paypal\View\Model\Profile;
 
         $params = array(
             'text_before' => static::t('Or register with'),
-            'buttonStyle' => 'icon',
+            'buttonStyle' => 'button',
         );
 
         $widget = $this->getWidget($params, 'XLite\Module\CDev\Paypal\View\Login\Widget');
