@@ -12,7 +12,7 @@ namespace XLite\Module\CDev\Sale\View\StickyPanel\Product\Admin;
 /**
  * Abstract product panel for admin interface
  */
- class AAdmin extends \XLite\Module\XC\BulkEditing\View\StickyPanel\Product\Admin\AAdmin implements \XLite\Base\IDecorator
+ class AAdmin extends \XLite\Module\CDev\Sale\View\StickyPanel\Product\Admin\Search implements \XLite\Base\IDecorator
 {
     /**
      * @inheritdoc
