@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\SalesTax\View\Menu\Admin;
 /**
  * Menu
  */
-abstract class AAdmin extends \XLite\Module\CDev\XPaymentsConnector\View\Menu\Admin\AAdmin implements \XLite\Base\IDecorator
+abstract class AAdmin extends \XLite\Module\XC\Upselling\View\Menu\AAdmin implements \XLite\Base\IDecorator
 {
     /**
      * Define and set handler attributes; initialize handler
