@@ -9,7 +9,7 @@
 namespace XLite\Module\CDev\SimpleCMS\Controller\Admin;
 
 
- class CacheManagement extends \XLite\Module\XC\ThemeTweaker\Controller\Admin\CacheManagement implements \XLite\Base\IDecorator
+ class CacheManagement extends \XLite\Controller\Admin\CacheManagementAbstract implements \XLite\Base\IDecorator
 {
     /**
      * Export action
