@@ -28,23 +28,6 @@ abstract class AView extends \XLite\Module\QSL\CloudSearch\View\AView implements
         return $list;
     }
 
-    /**
-     * Return favicon resource path
-     *
-     * @return string
-     */
-    protected function getFavicon()
-    {
-        $url = str_replace(LC_DS, '/', \XLite\Core\Config::getInstance()->CDev->SimpleCMS->favicon);
-
-
-        if (!$url) {
-            $url = parent::getFavicon();
-        }
-
-        return \XLite::getInstance()->getShopURL($url);
-    }
-
     /**
      * Flag if the favicon is displayed in the customer area
      *
