@@ -11,7 +11,7 @@ namespace XLite\Module\CDev\USPS\Model;
 /**
  * Class represents an order
  */
- class Order extends \XLite\Module\CDev\XPaymentsConnector\Model\Order implements \XLite\Base\IDecorator
+ class Order extends \XLite\Module\XC\CanadaPost\Model\Order implements \XLite\Base\IDecorator
 {
     /**
      * USPS Shipments
