@@ -37,12 +37,16 @@ namespace XLite\Module\QSL\BraintreeVZ\View\Payment;
      */
     protected function isVisible()
     {
-        $result = parent::isVisible()
-            && $this->isBraintreePaymentMethod();
+        if ($this->isBraintreePaymentMethod()) {
 
-        if ($result && !static::$_visible) {
-            static::$_visible = true;
-            $result = false;
+            $result = true;
+            if (!static::$_visible) {
+                static::$_visible = true;
+                $result = false;
+            }
+
+        } else {
+            $result = parent::isVisible();
         }
 
         return $result;
