@@ -8,6 +8,7 @@
 
 namespace XLite\Module\QSL\CloudSearch\Controller;
 
+use XLite\Module\QSL\CloudSearch\Core\IndexingEvent\IndexingEventProfiler;
 use XLite\Module\QSL\CloudSearch\Core\RegistrationScheduler;
 use XLite\Module\QSL\CloudSearch\Main;
 
@@ -30,4 +31,9 @@ abstract class AController extends \XLite\Module\XC\MailChimp\Controller\AContro
 
         parent::handleRequest();
     }
+
+    public function __destruct()
+    {
+        IndexingEventProfiler::getInstance()->log();
+    }
 }
