@@ -11,7 +11,7 @@ namespace XLite\Module\QSL\CloudSearch\Model\Repo\AttributeValue;
 /**
  * Attribute values repository
  */
-abstract class AAttributeValue extends \XLite\Model\Repo\AttributeValue\AAttributeValueAbstract implements \XLite\Base\IDecorator
+abstract class AAttributeValue extends \XLite\Module\XC\GoogleFeed\Model\Repo\AttributeValue\AAttributeValue implements \XLite\Base\IDecorator
 {
     /**
      * Find all attributes
