@@ -11,7 +11,7 @@ namespace XLite\Module\XC\BulkEditing\View\StickyPanel\Product\Admin;
 /**
  * Product list sticky panel
  */
-abstract class AAdmin extends \XLite\View\StickyPanel\Product\Admin\AAdminAbstract implements \XLite\Base\IDecorator
+abstract class AAdmin extends \XLite\Module\XC\FacebookMarketing\View\StickyPanel\Product\Admin\Search implements \XLite\Base\IDecorator
 {
     /**
      * Define additional buttons
@@ -25,7 +25,6 @@ abstract class AAdmin extends \XLite\View\StickyPanel\Product\Admin\AAdminAbstra
             'class'    => 'XLite\Module\XC\BulkEditing\View\Button\Product',
             'params'   => [
                 'style'          => 'more-action always-enabled',
-                'useCaretButton' => false,
                 'dropDirection'  => 'dropup',
             ],
             'position' => 50,
