@@ -8,7 +8,7 @@
 
 namespace XLite\Module\XC\Concierge\Core;
 
-abstract class Session extends \XLite\Core\SessionAbstract implements \XLite\Base\IDecorator
+abstract class Session extends \XLite\Module\XC\FacebookMarketing\Core\Session implements \XLite\Base\IDecorator
 {
     //protected function createSession()
     //{
