@@ -17,13 +17,16 @@ abstract class CommonResources extends \XLite\Module\XC\FastLaneCheckout\View\Co
         if (!(null === $adminZone ? \XLite::isAdminZone() : $adminZone)) {
             $list[static::RESOURCE_JS][] = 'js/bootstrap-tabcollapse.js';
             $list[static::RESOURCE_JS][] = 'js/jquery.collapser.js';
+            $list[static::RESOURCE_JS][] = [
+                'file' => 'js/jquery.actual.min.js',
+                'no_minify' => true
+            ];
             $list[static::RESOURCE_JS][] = 'js/jquery.floating-label.js';
             $list[static::RESOURCE_JS][] = 'js/jquery.path.js';
             $list[static::RESOURCE_JS][] = 'js/jquery.fly.js';
             $list[static::RESOURCE_JS][] = 'js/utils.js';
             $list[static::RESOURCE_JS][] = 'js/header.js';
             $list[static::RESOURCE_JS][] = 'js/footer.js';
-            $list[static::RESOURCE_CSS][] = 'css/lazy-load.css';
         }
 
         return $list;
