@@ -37,16 +37,4 @@ namespace XLite\Module\XC\CrispWhiteSkin\View\Product\Details\Customer;
     {
         return 4;
     }
-
-    /**
-     * @deprecated 5.3.4
-     *
-     * Checks if slider mode is required for the gallery
-     *
-     * @return boolean
-     */
-    protected function isInSliderMode()
-    {
-        return count($this->getProduct()->getPublicImages()) > $this->getMinCountForSlider();
-    }
 }
