@@ -11,7 +11,7 @@ namespace XLite\Module\XC\CustomerAttachments\Model\DTO\Product;
 /**
  * Product
  */
- class Info extends \XLite\Module\XC\FreeShipping\Model\DTO\Product\Info implements \XLite\Base\IDecorator
+ class Info extends \XLite\Module\XC\FacebookMarketing\Model\DTO\Product\Info implements \XLite\Base\IDecorator
 {
     /**
      * @param mixed|\XLite\Model\Product $object
