@@ -12,7 +12,7 @@ namespace XLite\Module\XC\CustomerAttachments\View\Product;
 /**
  * Product list item widget
  */
- class ListItem extends \XLite\Module\XC\FreeShipping\View\Product\ListItem implements \XLite\Base\IDecorator
+ class ListItem extends \XLite\Module\XC\FacebookMarketing\View\Product\ListItem implements \XLite\Base\IDecorator
 {
     /**
      * Return class attribute for the product cell
