@@ -3,4 +3,4 @@ namespace XLite\Module\XC\FastLaneCheckout\View\Sections;
 /**
  * Widget class of Payment section of the fastlane checkout
  */
-class Payment extends \XLite\Module\CDev\XPaymentsConnector\View\FastLaneCheckout\Payment {}
\ No newline at end of file
+class Payment extends \XLite\Module\XC\MailChimp\View\FastLane {}
\ No newline at end of file
