@@ -9,7 +9,9 @@
 namespace XLite\Module\XC\Geolocation\Controller\Admin;
 
 
- class Module extends \XLite\Controller\Admin\ModuleAbstract implements \XLite\Base\IDecorator
+use Includes\Utils\Module\Manager;
+
+ class Module extends \XLite\Module\XC\ProductFilter\Controller\Admin\Settings implements \XLite\Base\IDecorator
 {
     /**
      * Update module settings
@@ -20,14 +22,9 @@ namespace XLite\Module\XC\Geolocation\Controller\Admin;
     {
         parent::doActionUpdate();
 
-        if (
-            $this->getModule()
-            && $this->getModule()->getName() == 'Geolocation'
-            && $this->getModule()->getAuthor() == 'XC'
-        ) {
+        if ($this->getModule() === \Includes\Utils\Module\Module::buildId('XC', 'Geolocation')) {
             if (\XLite\Core\Request::getInstance()->restore_default_database) {
-                if (
-                    \XLite\Core\Config::getInstance()->XC->Geolocation->extended_db_path
+                if (\XLite\Core\Config::getInstance()->XC->Geolocation->extended_db_path
                     && file_exists(\XLite\Core\Config::getInstance()->XC->Geolocation->extended_db_path)
                 ) {
                     unlink(\XLite\Core\Config::getInstance()->XC->Geolocation->extended_db_path);
