@@ -23,7 +23,7 @@ namespace XLite\Module\XC\NotFinishedOrders\View\StickyPanel\Order\Admin;
         $list = parent::defineButtons();
 
         if ($this->getOrder()->isNotFinishedOrder()) {
-            $list['sendNotification'] = $this->getSendNotificationWidget();
+            $list['sendNotification'] = $this->getDoNotSendNotificationWidget();
         }
 
         return $list;
