@@ -11,7 +11,7 @@ namespace XLite\Module\XC\ProductFilter\Controller\Admin;
 /**
  * Settings page controller
  */
- class Settings extends \XLite\Controller\Admin\SettingsAbstract implements \XLite\Base\IDecorator
+ class Settings extends \XLite\Module\XC\Reviews\Controller\Admin\Module implements \XLite\Base\IDecorator
 {
     /**
      * Remove product filter cache
@@ -24,4 +24,4 @@ namespace XLite\Module\XC\ProductFilter\Controller\Admin;
 
         \XLite\Core\TopMessage::addInfo('The product filter cache has been removed successfully.');
     }
-}
\ No newline at end of file
+}
