@@ -26,7 +26,7 @@ namespace XLite\Module\XC\Reviews\View\Model;
     protected function isReviewModule()
     {
         if (!isset($this->isReviewModule)) {
-            $this->isReviewModule = $this->getModule() && 'XC\\Reviews' === $this->getModule()->getActualName();
+            $this->isReviewModule = $this->getModule() && 'XC-Reviews' === $this->getModule();
         }
 
         return $this->isReviewModule;
