@@ -17,24 +17,29 @@ namespace XLite\Module\XC\ThemeTweaker\Core\Templating\Twig\Loader;
 
         if (
             $result
-            && strpos($result, 'theme_tweaker') !== false
             && \XLite\Core\Layout::getInstance()->isDisabledTemplate($name)
         ) {
             $name = $this->normalizeName($name);
             list($namespace, $shortname) = $this->parseName($name);
 
+            $actual = false;
+
             foreach ($this->paths[$namespace] as $path) {
                 if (
                     strpos($path, 'theme_tweaker') === false
                     && is_file($path.'/'.$shortname)
                 ) {
                     if (false !== $realpath = realpath($path.'/'.$shortname)) {
-                        return $this->cache[$name] = $realpath;
+                        $actual = $realpath;
+                        break;
                     }
 
-                    return $this->cache[$name] = $path.'/'.$shortname;
+                    $actual = $path.'/'.$shortname;
+                    break;
                 }
             }
+
+            return $this->cache[$name] = $actual;
         }
 
         return $result;
