@@ -21,7 +21,7 @@ abstract class AView extends \XLite\View\AViewAbstract implements \XLite\Base\ID
     {
         $list = parent::getCSSFiles();
         if (\XLite::isAdminZone()) {
-            $list[] = 'modules/XC/VendorMessages/style.css';
+            $list[] = 'modules/XC/VendorMessages/style.less';
         }
 
         return $list;
