@@ -11,7 +11,7 @@ namespace XLite\Module\XC\VendorMessages\View\ItemsList\Model\Order\Admin;
 /**
  * Search order
  */
- class Search extends \XLite\View\ItemsList\Model\Order\Admin\SearchAbstract implements \XLite\Base\IDecorator
+ class Search extends \XLite\Module\XPay\XPaymentsCloud\View\ItemsList\Model\Order\Admin\Search implements \XLite\Base\IDecorator
 {
     /**
      * Widget param names
