@@ -220,7 +220,7 @@ abstract class AResourcesContainerAbstract extends \XLite\View\Container
      */
     protected function minifyCSS($content, $filePath)
     {
-        $minifier = new \CSSmin();
+        $minifier = new \tubalmartin\CssMin\Minifier();
 
         return $minifier->run($content);
     }
@@ -369,7 +369,8 @@ abstract class AResourcesContainerAbstract extends \XLite\View\Container
     protected function doCSSOptimization()
     {
         return $this->doCSSAggregation()
-            && \Includes\Utils\ConfigParser::getOptions(['storefront_options', 'optimize_css']);
+            && \Includes\Utils\ConfigParser::getOptions(['storefront_options', 'optimize_css'])
+            && !\XLite\Core\Request::getInstance()->isIE(); // Disable CSS optimization for IE, BUG-6818
     }
 
     /**
@@ -540,7 +541,7 @@ abstract class AResourcesContainerAbstract extends \XLite\View\Container
             }
         }
 
-        $webDir = ConfigParser::getOptions(['host_details', 'web_dir']);
+        $webDir = ConfigParser::getOptions(['host_details', 'web_dir_wo_slash']);
 
         $content = preg_replace_callback(
             '/url\(([^)]+)\)/Ss',
@@ -551,7 +552,8 @@ abstract class AResourcesContainerAbstract extends \XLite\View\Container
                     !preg_match('/^[\'"]?data:/Ss', $matches[1])
                     && !preg_match('/^(?:https?:)?\/\//Ss', $matches[1])
                 ) {
-                    return 'url(' . $webDir . '/' . mb_substr($relativeUrl, 4);
+                    $prefix = $webDir ? $webDir . '/' : '';
+                    return 'url(' . $prefix . mb_substr($relativeUrl, 4);
                 }
 
                 return $relativeUrl;
