@@ -32,7 +32,7 @@ abstract class SimpleFormAbstract extends \XLite\View\Form\Product\Search\Custom
     protected function getDefaultParams()
     {
         return parent::getDefaultParams() + array(
-            \XLite\View\ItemsList\Product\Customer\Search::PARAM_INCLUDING => \XLite\Model\Repo\Product::INCLUDING_ANY,
+            \XLite\View\ItemsList\Product\Customer\Search::PARAM_INCLUDING => \XLite\Model\Repo\Product::INCLUDING_ALL,
         );
     }
 }
