@@ -11,7 +11,7 @@ namespace XLite\View\FormField\Input;
 /**
  * Password
  */
-class Password extends \XLite\View\FormField\Input\Secure
+class Password extends \XLite\View\FormField\Input\Secure implements \XLite\Core\PreloadedLabels\ProviderInterface
 {
     /**
      * setCommonAttributes
@@ -37,4 +37,16 @@ class Password extends \XLite\View\FormField\Input\Secure
     {
         return true;
     }
+
+    /**
+     * Array of labels in following format.
+     *
+     * 'label' => 'translation'
+     *
+     * @return mixed
+     */
+    public function getPreloadedLanguageLabels()
+    {
+        return $this->getPasswordDifficultyLabels();
+    }
 }
