@@ -23,6 +23,7 @@ abstract class AItemsListAbstract extends \XLite\View\Container
      */
     const PARAM_SORT_BY    = 'sortBy';
     const PARAM_SORT_ORDER = 'sortOrder';
+    const PARAM_AJAX_ITEMS_PER_PAGE = 'itemsPerPage';
 
     /**
      * SQL orderby directions
@@ -209,13 +210,14 @@ abstract class AItemsListAbstract extends \XLite\View\Container
     {
         $list = parent::getCSSFiles();
         // Static call of the non-static function
+        $list[] = self::getDir() . '/items_list.less';
         $list[] = self::getDir() . '/items_list.css';
         $list = self::preparePagerCSSFiles($list);
 
         $list[] = 'form_field/inline/style.css';
         $list[] = 'form_field/input/price.css';
         $list[] = 'form_field/input/symbol.css';
-        $list[] = 'form_field/input/checkbox/switcher.css';
+        //$list[] = 'form_field/input/checkbox/switcher.css'; // TODO: less ajax loading
 
         return $list;
     }
@@ -879,7 +881,7 @@ abstract class AItemsListAbstract extends \XLite\View\Container
                 $preprocessed = $condition->getValue();
             }
 
-            if (!$preprocessed || !is_string($preprocessed)) {
+            if (!$preprocessed || !(is_string($preprocessed) || is_array($preprocessed))) {
                 continue;
             }
 
@@ -899,6 +901,7 @@ abstract class AItemsListAbstract extends \XLite\View\Container
         return array(
             static::PARAM_AJAX_WIDGET => get_class($this),
             static::PARAM_AJAX_TARGET => \XLite\Core\Request::getInstance()->target,
+            static::PARAM_AJAX_ITEMS_PER_PAGE => $this->getPager()->getWidgetParams('itemsPerPage')->value
         );
     }
 
