@@ -76,6 +76,7 @@ abstract class APagerAbstract extends \XLite\View\RequestHandler\ARequestHandler
     public function getCSSFiles()
     {
         $list = parent::getCSSFiles();
+        $list[] = $this->getDir() . '/pager.less';
         $list[] = $this->getDir() . '/pager.css';
 
         if (!\XLite::isAdminZone()) {
@@ -175,6 +176,16 @@ abstract class APagerAbstract extends \XLite\View\RequestHandler\ARequestHandler
         return 'pager';
     }
 
+    /**
+     * getPagerLabel
+     *
+     * @return label
+     */
+    protected function getPagerLabel()
+    {
+        return static::t('Products');
+    }
+
     /**
      * Return widget default template
      *
