@@ -5,4 +5,4 @@ namespace XLite\View\Tabs;
  *
  * @ListChild (list="admin.center", zone="admin")
  */
-class AdminProfile extends \XLite\Module\CDev\XPaymentsConnector\View\Tabs\AdminProfile {}
\ No newline at end of file
+class AdminProfile extends \XLite\Module\QSL\BraintreeVZ\View\Tabs\AdminProfile {}
\ No newline at end of file
